## PRELIMINARIES 
# Need to run this code in R 64
# Need to install the following R packages: ggplot2, coda, MCMCpack, mvtnorm, spam, grid, nnet, psych, usdm, ltm, perturb


options(warn=-1)
setwd("//isad.isadroot.ex.ac.uk/UOE/User/Desktop/Replication CPS/Data and Replication files")

################################## FIGURE 1 #####################################################################################################################################################################################################
#####  Figure 1
library(ggplot2)
df<-read.csv("data.survival.csv")


Joint<-rbind(cbind(rownames(by(df$merged, df$year_exist,sum)),
by(df$merged, df$year_exist,sum), "Mergers"),
cbind(rownames(by(df$merged, df$year_exist,sum)),
by(df$dissolved, df$year_exist,sum), "Dissolutions"))
Joint<-data.frame(Joint)
names(Joint)<-c("Life", "Death", "Type")
Joint$Life<- as.numeric(levels(Joint$Life))[Joint$Life]
Joint$Death<- as.numeric(levels(Joint$Death))[Joint$Death]


ggplot(Joint,aes(x=Life,y=Death))+
  geom_bar(stat="identity", fill="gray")+theme_bw()+xlab("Party Age (in years)")+
	ylab("Number of Parties")+
	scale_x_continuous(limits=c(0,41), breaks = c(seq(0,40,by=10)))+
	facet_wrap(~ Type, scales="free_x")+
     theme(strip.text.x = element_text(size = 12, face="bold"))


################################## TABLE 2 #####################################################################################################################################################################################################
library(MCMCpack)
library(mvtnorm)
library(spam)

# COLUMNS 1 AND 2

df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))
df$years.centered<-(df$year_exist-mean(df$year_exist))/(2*sd(df$year_exist))
df$years.centered.squared<-df$years.centered^2
df$years.centered.squared.bis<-(df$year_exist^2-mean(df$year_exist^2))/(2*sd(df$year_exist^2,na.rm=TRUE))

df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"years.centered","year_exist",
		"years.centered.squared", "years.centered.squared.bis"))

df<-na.exclude(df)


country<-as.numeric(factor(df$country.id), levels=unique(df$country.id))
party<-as.numeric(factor(df$party.id), levels=unique(df$party.id))
num.country<-length(unique(country))
num.party<-length(unique(party))

# 1= survive, 2=merge, 3=dissolve
Y<-cbind(df$merged, df$dissolved)
Y<-cbind(ifelse(rowSums(Y)==0,1,0),Y)
y<-c(sapply(1:nrow(Y), function(i) which(Y[i,]==1)))
n<-length(y)          # Number of obs
K<-3			    # Number of outcomes


Matrix.Country<-as.spam(matrix(0,n,num.country))
for (i in 1:num.country) Matrix.Country[country==i,i]<-1

Matrix.Party<-as.spam(matrix(0,n,num.party))
for (i in 1:num.party) Matrix.Party[party==i,i]<-1


X<-cbind(1,  df$years.centered, df$years.centered.squared,
		 df$organisation, df$newfamfirst,
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,df$election_year_dummy,
		df$indPOL, df$efNPP,  
		df$elec_coalition, 
		df$votes.history.centered, 
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)


colnames(X)<-c("Intercept", "Party.Life.Length", "Party.Life.Length.Squared",
		"Organisation", "NewFamFirst",
		  "DM","DM.squared", "Finance", "Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament", "Regional")



# Iterations &  burn-in
 nsim<-3000000				# Number of MCMC Iterations
 thin<-100                          # Thinning Interval (should be a divisor of nsim/2)
 burn<-250000                       # Burn-in
 lastit<-(nsim-burn)/thin	      # Last stored value

# Priors
set.seed(26135)
mu0<-rep(0,ncol(X))
Tau0<-diag(1,ncol(X))
Sigma0<-solve(Tau0)

# Store Values
 Beta2<-Beta3<-array(0,c(lastit,ncol(X),3)) 
 Sigma.country<-array(0, c(lastit,4,3))
 Sigma.party<-array(0, c(lastit,4,3))
 Reffect.country<-array(0,c(lastit,num.country*2,3))
 Reffect.party<-array(0,c(lastit,num.party*2,3))


for (ch in 1:3) {

# Inits
  b2<-rep(0,ncol(X))
  b3<-rep(0,ncol(X))
  cov2<-cov3<-0.01*diag(ncol(X))
  reffect.country<-matrix(0, num.country,2) 
  sigma.country<-diag(2)
   reffect.party<-matrix(0, num.party,2) 
  sigma.party<-diag(2)
 

A<-0

for (i in 1:nsim) {
 # Calculate Likelihood based on old value of b2 and b3
  eta2<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]

  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lold<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))

 # Draw Candidates
  b2new<-b2 + rmvt(1,sigma=.005*cov2,3)  # Tuning parameter to reach appropriate acceptance rate	
  b3new<-b3 + rmvt(1,sigma=.005*cov3,3)   	

 eta2<-X%*%c(b2new)+reffect.country[country,1]+reffect.party[party,1]
  eta3<-X%*%c(b3new)+reffect.country[country,2]+reffect.party[party,2]
  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lnew<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))


# Acceptance prob on log scale
   r<-lnew+dmvnorm(b2new,mu0,Sigma0,log=T)+dmvnorm(b3new,mu0,Sigma0,log=T)-	
	(lold+dmvnorm(b2,mu0,Sigma0,log=T)+dmvnorm(b3,mu0,Sigma0,log=T))
   if(!is.na(r) & log(runif(1))<r){
    b2<-c(b2new)
    b3<-c(b3new)  
    A<-A+1
    }


###################################
# Update Country reffects using MH #
 ##################################
 reffect.country.new<-reffect.country+rmvt(num.country,sigma=0.001*diag(2),3) 
  eta2.old<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3.old<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X%*%b2+reffect.country.new[country,1]+reffect.party[party,1]
 eta3.new<-X%*%b3+reffect.country.new[country,2]+reffect.party[party,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Country)%*%(l.new-l.old)) + 
	dmvnorm(reffect.country.new,rep(0,2),sigma.country, log=TRUE)-
	dmvnorm(reffect.country,rep(0,2),sigma.country, log=TRUE)
 if (!is.na(sum(ratio))) {
u<-(log(runif(num.country))<  ratio)*1
  reffect.country[!is.na(u) & u==1,]<-reffect.country.new[!is.na(u) & u==1,]
   reffect.country[,1]<-reffect.country[,1]-mean(reffect.country[,1])
   reffect.country[,2]<-reffect.country[,2]-mean(reffect.country[,2])

 ########################
 # Update sigma.country #
 #########################
sigma.country<-riwish(num.country+3, .01*diag(2)+crossprod(reffect.country))
}    

###################################
# Update Party reffects using MH #
 ##################################
 reffect.party.new<-reffect.party+rmvt(num.party,sigma=0.001*diag(2),3) 
  eta2.old<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3.old<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X%*%b2+reffect.country[country,1]+reffect.party.new[party,1]
 eta3.new<-X%*%b3+reffect.country[country,2]+reffect.party.new[party,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Party)%*%(l.new-l.old)) + 
	dmvnorm(reffect.party.new,rep(0,2),sigma.party, log=TRUE)-
	dmvnorm(reffect.party,rep(0,2),sigma.party, log=TRUE)
 if (!is.na(sum(ratio))) {
 u<-(log(runif(num.party))<  ratio)*1
  reffect.party[!is.na(u) & u==1,]<-reffect.party.new[!is.na(u) & u==1,]
   reffect.party[,1]<-reffect.party[,1]-mean(reffect.party[,1])
   reffect.party[,2]<-reffect.party[,2]-mean(reffect.party[,2])

 ########################
 # Update sigma.party #
 #########################
sigma.party<-riwish(num.party+3, .01*diag(2)+crossprod(reffect.party))
}    
  
# Store Results
  if (i> burn & i%%thin==0) {
    j<-(i-burn)/thin
   Beta2[j,,ch]<-b2
   Beta3[j,,ch]<-b3
   Sigma.country[j,,ch]<-c(sigma.country)
   Reffect.country[j,,ch]<-as.vector(reffect.country)
   Sigma.party[j,,ch]<-c(sigma.party)
   Reffect.party[j,,ch]<-as.vector(reffect.party)
}


if (i%%1000==0)  print(c(ch, i, A/i))


# Backup saving (if something goes wrong)
if (i==nsim) {

Results<-list(Beta2=Beta2[,,ch], Beta3=Beta3[,,ch], 
			Sigma.country=Sigma.country[,,ch], 
			Reffect.country=Reffect.country[,,ch],
			Sigma.party=Sigma.party[,,ch], 
			Reffect.party=Reffect.party[,,ch],
			vars=colnames(X))

save(Results, file=paste("Table 2, Cols 1-2, chain=", ch))

}

}

} 
# End of MCMC algorithm



## Convergence checks
library(coda)
BETA2<-mcmc.list(as.mcmc(Beta2[,,1]), as.mcmc(Beta2[,,2]), 
		as.mcmc(Beta2[,,3]))
BETA3<-mcmc.list(as.mcmc(Beta3[,,1]), as.mcmc(Beta3[,,2]), 
		as.mcmc(Beta3[,,3]))
SIGMA.COUNTRY<-mcmc.list(as.mcmc(Sigma.country[,-3,1]), 
as.mcmc(Sigma.country[,-3,2]), as.mcmc(Sigma.country[,-3,3]))
SIGMA.PARTY<-mcmc.list(as.mcmc(Sigma.party[,-3,1]),
	 as.mcmc(Sigma.party[,-3,2]), as.mcmc(Sigma.party[,-3,3]))

gelman.diag(BETA2)[[2]]<1.2
gelman.diag(BETA3)[[2]]<1.2
gelman.diag(SIGMA.COUNTRY)[[2]]<1.2
gelman.diag(SIGMA.PARTY)[[2]]<1.2

All.Results<-list(Beta2=Beta2, Beta3=Beta3, 
			Sigma.country=Sigma.country, 
			Reffect.country=Reffect.country,
			Sigma.party=Sigma.party, 
			Reffect.party=Reffect.party,
			vars=colnames(X))
save(All.Results, file="All.Results.Table2.Cols12")


Beta.2<-rbind(All.Results$Beta2[26751:27500,,1], All.Results$Beta2[26751:27500,,2], All.Results$Beta2[26751:27500,,3])
Beta.3<-rbind(All.Results$Beta3[26751:27500,,1], All.Results$Beta3[26751:27500,,2], All.Results$Beta3[26751:27500,,3])
colnames(Beta.2)<-All.Results$vars
colnames(Beta.3)<-All.Results$vars
Sigma.Country<-rbind(All.Results$Sigma.country[26751:27500,,1], All.Results$Sigma.country[26751:27500,,2], All.Results$Sigma.country[26751:27500,,3])
Sigma.Party<-rbind(All.Results$Sigma.party[26751:27500,,1], All.Results$Sigma.party[26751:27500,,2], All.Results$Sigma.party[26751:27500,,3])
Reffect.Country<-rbind(All.Results$Reffect.country[26751:27500,,1],All.Results$Reffect.country[26751:27500,,2], All.Results$Reffect.country[26751:27500,,3])
Reffect.Country.Merge<-Reffect.Country[,1:num.country]
Reffect.Country.Dissolution<-Reffect.Country[,(num.country+1):(2*num.country)]
Reffect.Party<-rbind(All.Results$Reffect.party[26751:27500,,1],All.Results$Reffect.party[26751:27500,,2], All.Results$Reffect.party[26751:27500,,3])
Reffect.Party.Merge<-Reffect.Party[,1:num.party]
Reffect.Party.Dissolution<-Reffect.Party[,(num.party+1):(2*num.party)]


# Table 2, Column 1 
Determinants.Dissolution<-round(cbind(colMeans(Beta.3),HPDinterval(as.mcmc(Beta.3), p=0.9)),digits=3)
colnames(Determinants.Dissolution)<-c("Estimate", "CI - Lower", "CI - Higher")
Determinants.Dissolution


# Table 2, Column 2
Determinants.Mergers<-round(cbind(colMeans(Beta.2),HPDinterval(as.mcmc(Beta.2), p=0.9)),digits=3)
colnames(Determinants.Mergers)<-c("Estimate", "CI - Lower", "CI - Higher")
Determinants.Mergers

## Table 2, Cols 1 and 2, chi-squared p-value
# Percent correctly predicted
mean.predicted.probs<-cbind(1/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])),
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])),
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])))

# Chi-squared goodness of fit test 
# H0: Data is consistent with the fitted model
observed<-sapply(1:3, function(k) sum(Y[,k]))
expected<-sapply(1:3, function(k) sum(mean.predicted.probs[,k]))/nrow(X)

chisq.test(observed, p=expected)$p.value  				


rm(list=ls())


# COLUMNS 3 AND 4
df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))


df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"year_exist"))
df<-na.exclude(df)

country<-as.numeric(factor(df$country.id), levels=unique(df$country.id))
party<-as.numeric(factor(df$party.id), levels=unique(df$party.id))
duration<-as.numeric(factor(df$year_exist), levels=unique(df$year_exist))
num.country<-length(unique(country))
num.party<-length(unique(party))
num.duration<-length(unique(duration))

# 1= survive, 2=merge, 3=dissolve
Y<-cbind(df$merged, df$dissolved)
Y<-cbind(ifelse(rowSums(Y)==0,1,0),Y)
y<-c(sapply(1:nrow(Y), function(i) which(Y[i,]==1)))
n<-length(y)          # Number of obs
K<-3			    # Number of outcomes


Matrix.Country<-as.spam(matrix(0,n,num.country))
for (i in 1:num.country) Matrix.Country[country==i,i]<-1

Matrix.Party<-as.spam(matrix(0,n,num.party))
for (i in 1:num.party) Matrix.Party[party==i,i]<-1

Matrix.Duration<-as.spam(matrix(0,n,num.duration))
for (i in 1:num.duration) Matrix.Duration[duration==i,i]<-1

X<-cbind(1,  df$organisation, df$newfamfirst,
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,df$election_year_dummy,
		df$indPOL, df$efNPP,  
		df$elec_coalition, 
		df$votes.history.centered, 
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)

colnames(X)<-c("Intercept", "Social Rootedness", "New Family",
		  "DM","DM.squared", "Finance", "Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament", "Regional.Government")


# Iterations &  burn-in
 nsim<-3000000				# Number of MCMC Iterations
 thin<-100                          # Thinning Interval (should be a divisor of nsim/2)
 burn<-250000                       # Burn-in
 lastit<-(nsim-burn)/thin	      # Last stored value

# Priors
set.seed(115524)
mu0<-rep(0,ncol(X))
Tau0<-diag(1,ncol(X))
Sigma0<-solve(Tau0)

# Store Values
 Beta2<-Beta3<-array(0,c(lastit,ncol(X),3)) 
 Sigma.country<-array(0, c(lastit,4,3))
 Sigma.party<-array(0, c(lastit,4,3))
 Reffect.country<-array(0,c(lastit,num.country*2,3))
 Reffect.party<-array(0,c(lastit,num.party*2,3))
 Reffect.duration<-array(0,c(lastit,num.duration*2,3))
 Sigma.duration<-array(0, c(lastit,4,3))


for (ch in 1:3) {

# Inits
  b2<-rep(0,ncol(X))
  b3<-rep(0,ncol(X))
  cov2<-cov3<-0.01*diag(ncol(X))
  reffect.country<-matrix(0, num.country,2) 
  sigma.country<-diag(2)
   reffect.party<-matrix(0, num.party,2) 
  sigma.party<-diag(2)
  reffect.duration<-matrix(0, num.duration,2) 
 sigma.duration<-diag(2)

A<-0

for (i in 1:nsim) {
 # Calculate Likelihood based on old value of b2 and b3
  eta2<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]+reffect.duration[duration,1]
  eta3<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]+reffect.duration[duration,2]

  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lold<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))

 # Draw Candidates
  b2new<-b2 + rmvt(1,sigma=.005*cov2,3)  # Tuning parameter to reach appropriate acceptance rate	
  b3new<-b3 + rmvt(1,sigma=.005*cov3,3)   	

 eta2<-X%*%c(b2new)+reffect.country[country,1]+reffect.party[party,1]+reffect.duration[duration,1]
  eta3<-X%*%c(b3new)+reffect.country[country,2]+reffect.party[party,2]+reffect.duration[duration,2]
  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lnew<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))


# Acceptance prob on log scale
   r<-lnew+dmvnorm(b2new,mu0,Sigma0,log=T)+dmvnorm(b3new,mu0,Sigma0,log=T)-	
	(lold+dmvnorm(b2,mu0,Sigma0,log=T)+dmvnorm(b3,mu0,Sigma0,log=T))
   if(log(runif(1))<r){
    b2<-c(b2new)
    b3<-c(b3new)  
    A<-A+1
    }


###################################
# Update Country reffects using MH #
 ##################################
 reffect.country.new<-reffect.country+rmvt(num.country,sigma=0.001*diag(2),3) 
  eta2.old<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]+reffect.duration[duration,1]
  eta3.old<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]+reffect.duration[duration,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X%*%b2+reffect.country.new[country,1]+reffect.party[party,1]+reffect.duration[duration,1]
 eta3.new<-X%*%b3+reffect.country.new[country,2]+reffect.party[party,2]+reffect.duration[duration,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Country)%*%(l.new-l.old)) + 
	dmvnorm(reffect.country.new,rep(0,2),sigma.country, log=TRUE)-
	dmvnorm(reffect.country,rep(0,2),sigma.country, log=TRUE)
 u<-(log(runif(num.country))<  ratio)*1
  reffect.country[!is.na(u) & u==1,]<-reffect.country.new[!is.na(u) & u==1,]
   reffect.country[,1]<-reffect.country[,1]-mean(reffect.country[,1])
   reffect.country[,2]<-reffect.country[,2]-mean(reffect.country[,2])

 ########################
 # Update sigma.country #
 #########################
sigma.country<-riwish(num.country+3, .01*diag(2)+crossprod(reffect.country))
    

###################################
# Update Party reffects using MH #
 ##################################
 reffect.party.new<-reffect.party+rmvt(num.party,sigma=0.001*diag(2),3) 
  eta2.old<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]+reffect.duration[duration,1]
  eta3.old<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]+reffect.duration[duration,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X%*%b2+reffect.country[country,1]+reffect.party.new[party,1]+reffect.duration[duration,1]
 eta3.new<-X%*%b3+reffect.country[country,2]+reffect.party.new[party,2]+reffect.duration[duration,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Party)%*%(l.new-l.old)) + 
	dmvnorm(reffect.party.new,rep(0,2),sigma.party, log=TRUE)-
	dmvnorm(reffect.party,rep(0,2),sigma.party, log=TRUE)
 u<-(log(runif(num.party))<  ratio)*1
  reffect.party[!is.na(u) & u==1,]<-reffect.party.new[!is.na(u) & u==1,]
   reffect.party[,1]<-reffect.party[,1]-mean(reffect.party[,1])
   reffect.party[,2]<-reffect.party[,2]-mean(reffect.party[,2])

 ########################
 # Update sigma.party #
 #########################
sigma.party<-riwish(num.party+3, .01*diag(2)+crossprod(reffect.party))
    
  
###################################
# Update Duration reffects using MH #
 ##################################
 reffect.duration.new<-reffect.duration+rmvt(num.duration,sigma=0.001*diag(2),3) 
  eta2.old<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]+reffect.duration[duration,1]
  eta3.old<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]+reffect.duration[duration,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]+reffect.duration.new[duration,1]
 eta3.new<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]+reffect.duration.new[duration,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Duration)%*%(l.new-l.old)) + 
	dmvnorm(reffect.duration.new,rep(0,2),sigma.duration, log=TRUE)-
	dmvnorm(reffect.duration,rep(0,2),sigma.duration, log=TRUE)
 u<-(log(runif(num.duration))<  ratio)*1
  reffect.duration[!is.na(u) & u==1,]<-reffect.duration.new[!is.na(u) & u==1,]
   reffect.duration[,1]<-reffect.duration[,1]-mean(reffect.duration[,1])
   reffect.duration[,2]<-reffect.duration[,2]-mean(reffect.duration[,2])

 ########################
 # Update sigma.duration #
 #########################
sigma.duration<-riwish(num.duration+3, .01*diag(2)+crossprod(reffect.duration))
    
# Store Results
  if (i> burn & i%%thin==0) {
    j<-(i-burn)/thin
   Beta2[j,,ch]<-b2
   Beta3[j,,ch]<-b3
   Sigma.country[j,,ch]<-c(sigma.country)
   Reffect.country[j,,ch]<-as.vector(reffect.country)
   Sigma.party[j,,ch]<-c(sigma.party)
   Reffect.party[j,,ch]<-as.vector(reffect.party)
   Sigma.duration[j,,ch]<-c(sigma.duration)
   Reffect.duration[j,,ch]<-as.vector(reffect.duration)
}


if (i%%1000==0)  print(c(ch, i, A/i))


# Backup saving (if something goes wrong)
if (i==nsim) {

Results<-list(Beta2=Beta2[,,ch], Beta3=Beta3[,,ch], 
			Sigma.country=Sigma.country[,,ch], 
			Reffect.country=Reffect.country[,,ch],
			Sigma.party=Sigma.party[,,ch], 
			Reffect.party=Reffect.party[,,ch],
			Sigma.duration=Sigma.duration[,,ch], 
			Reffect.duration=Reffect.duration[,,ch],
			vars=colnames(X))

save(Results, file=paste("Table 2, Cols 3-4, chain=", ch))}

}

} # End of MCMC algorithm


## Convergence checks
BETA2<-mcmc.list(as.mcmc(Beta2[,,1]), as.mcmc(Beta2[,,2]), 
		as.mcmc(Beta2[,,3]))
BETA3<-mcmc.list(as.mcmc(Beta3[,,1]), as.mcmc(Beta3[,,2]), 
		as.mcmc(Beta3[,,3]))
SIGMA.COUNTRY<-mcmc.list(as.mcmc(Sigma.country[,-3,1]), 
as.mcmc(Sigma.country[,-3,2]), as.mcmc(Sigma.country[,-3,3]))
SIGMA.PARTY<-mcmc.list(as.mcmc(Sigma.party[,-3,1]),
	 as.mcmc(Sigma.party[,-3,2]), as.mcmc(Sigma.party[,-3,3]))
SIGMA.DURATION<-mcmc.list(as.mcmc(Sigma.duration[,-3,1]), as.mcmc(Sigma.duration[,-3,2]), as.mcmc(Sigma.duration[,-3,3]))

gelman.diag(BETA2)[[2]]<1.2
gelman.diag(BETA3)[[2]]<1.2
gelman.diag(SIGMA.COUNTRY)[[2]]<1.2
gelman.diag(SIGMA.PARTY)[[2]]<1.2
gelman.diag(SIGMA.DURATION)[[2]]<1.2


All.Results<-list(Beta2=Beta2, Beta3=Beta3, 
			Sigma.country=Sigma.country, 
			Reffect.country=Reffect.country,
			Sigma.party=Sigma.party, 
			Reffect.party=Reffect.party,
			Reffect.duration=Reffect.duration,
			vars=colnames(X))

save(All.Results, file="All.Results.Table2.Cols34")


Beta.2<-rbind(All.Results$Beta2[27291:27500,,1], All.Results$Beta2[27291:27500,,2], All.Results$Beta2[27291:27500,,3])
Beta.3<-rbind(All.Results$Beta3[27291:27500,,1], All.Results$Beta3[27291:27500,,2], All.Results$Beta3[27291:27500,,3])
colnames(Beta.2)<-All.Results$vars
colnames(Beta.3)<-All.Results$vars
Sigma.Country<-rbind(All.Results$Sigma.country[27291:27500,,1], All.Results$Sigma.country[27291:27500,,2], All.Results$Sigma.country[27291:27500,,3])
Sigma.Party<-rbind(All.Results$Sigma.party[27291:27500,,1], All.Results$Sigma.party[27291:27500,,2], All.Results$Sigma.party[27291:27500,,3])
Reffect.Country<-rbind(All.Results$Reffect.country[27291:27500,,1],All.Results$Reffect.country[27291:27500,,2], All.Results$Reffect.country[27291:27500,,3])
Reffect.Duration<-rbind(All.Results$Reffect.duration[27291:27500,,1],All.Results$Reffect.duration[27291:27500,,2], All.Results$Reffect.duration[27291:27500,,3])
Reffect.Party<-rbind(All.Results$Reffect.party[27291:27500,,1],All.Results$Reffect.party[27291:27500,,2], All.Results$Reffect.party[27291:27500,,3])


# Table 2, Column 3
Determinants.Dissolution<-round(cbind(colMeans(Beta.3),HPDinterval(as.mcmc(Beta.3), p=0.9)),digits=3)
colnames(Determinants.Dissolution)<-c("Estimate", "CI - Lower", "CI - Higher")
Determinants.Dissolution

# Table 2, Column 4
Determinants.Mergers<-round(cbind(colMeans(Beta.2),HPDinterval(as.mcmc(Beta.2), p=0.9), digits=3)
colnames(Determinants.Mergers)<-c("Estimate", "CI - Lower", "CI - Higher")
Determinants.Mergers


## Table 2, Cols 3 and 4, chi-squared p-value
# Percent correctly predicted
mean.predicted.probs<-cbind(1/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,1])),
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,1])/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,1])),
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,2])/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1]+matrix(apply(Reffect.Duration,2,mean),ncol=2)[duration,1])))

# Chi-squared goodness of fit test 
# H0: Data is consistent with the fitted model
observed<-sapply(1:3, function(k) sum(Y[,k]))
expected<-sapply(1:3, function(k) sum(mean.predicted.probs[,k]))/nrow(X)

chisq.test(observed, p=expected)$p.value  							#



rm(list=ls())
########################## FIGURE 2 #####################################################################################################################################################################################################
df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))
df$years.centered<-(df$year_exist-mean(df$year_exist))/(2*sd(df$year_exist))
df$years.centered.squared<-df$years.centered^2
df$years.centered.squared.bis<-(df$year_exist^2-mean(df$year_exist^2))/(2*sd(df$year_exist^2,na.rm=TRUE))

df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"years.centered","year_exist",
		"years.centered.squared", "years.centered.squared.bis"))

df<-na.exclude(df)


country<-as.numeric(factor(df$country.id), levels=unique(df$country.id))
party<-as.numeric(factor(df$party.id), levels=unique(df$party.id))
num.country<-length(unique(country))
num.party<-length(unique(party))

X<-cbind(1,  df$years.centered, df$years.centered.squared,
		 df$organisation, df$newfamfirst,
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,df$election_year_dummy,
		df$indPOL, df$efNPP,  
		df$elec_coalition, 
		df$votes.history.centered, 
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)


colnames(X)<-c("Intercept", "Party.Life.Length", "Party.Life.Length.Squared",
		"Organisation", "NewFamFirst",
		  "DM","DM.squared", "Finance", "Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament", "Regional")


load("All.Results.Table2.Cols12")


### Posterior Summaries
Beta.2<-rbind(All.Results$Beta2[26751:27500,,1], All.Results$Beta2[26751:27500,,2], All.Results$Beta2[26751:27500,,3])
Beta.3<-rbind(All.Results$Beta3[26751:27500,,1], All.Results$Beta3[26751:27500,,2], All.Results$Beta3[26751:27500,,3])
colnames(Beta.2)<-All.Results$vars
colnames(Beta.3)<-All.Results$vars
Sigma.Country<-rbind(All.Results$Sigma.country[26751:27500,,1], All.Results$Sigma.country[26751:27500,,2], All.Results$Sigma.country[26751:27500,,3])
Sigma.Party<-rbind(All.Results$Sigma.party[26751:27500,,1], All.Results$Sigma.party[26751:27500,,2], All.Results$Sigma.party[26751:27500,,3])
Reffect.Country<-rbind(All.Results$Reffect.country[26751:27500,,1],All.Results$Reffect.country[26751:27500,,2], All.Results$Reffect.country[26751:27500,,3])
Reffect.Country.Merge<-Reffect.Country[,1:num.country]
Reffect.Country.Dissolution<-Reffect.Country[,(num.country+1):(2*num.country)]
Reffect.Party<-rbind(All.Results$Reffect.party[26751:27500,,1],All.Results$Reffect.party[26751:27500,,2], All.Results$Reffect.party[26751:27500,,3])
Reffect.Party.Merge<-Reffect.Party[,1:num.party]
Reffect.Party.Dissolution<-Reffect.Party[,(num.party+1):(2*num.party)]


## Marginal Effects
dummies<-c(4, 5, 8, 9,12,15, 16,17)
continuous<-c(10, 11, 13, 14)

Marginal.prob<-matrix(NA, nrow=(2+length(dummies)+length(continuous))*2, ncol=5)
colnames(Marginal.prob)<-c("Dep.Variable", "Covariate", "Predictive Comparison",  "90% CI - Lower", "90% CI - Higher")
Marginal.prob[,1]<-c(rep("Dissolution",(2+length(dummies)+length(continuous))) ,rep("Merger",(2+length(dummies)+length(continuous))))
Marginal.prob[,2]<-rep(colnames(X)[sort(c(2,6,dummies, continuous))],2)

for (j in dummies) {
X.0<-X
X.0[,j]<-0
X.1<-X
X.1[,j]<-1

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)
}

for (j in continuous) {
X.0<-X
X.1<-X
X.1[,j]<-X.0[,j]+sd(X[,j])

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)


Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)
}
 
# Duration
X.0<-X
X.1<-X
X.1[,2]<-X[,2]+sd(X[,2])
X.1[,3]<-X.1[,2]^2

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Marginal.prob[grep(colnames(X)[2],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[2],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)


# Quadratic term for DM
X.0<-X
X.1<-X
X.1[,6]<-X[,6]+sd(X[,6])
X.1[,7]<-X.1[,6]^2

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Marginal.prob[grep(colnames(X)[6],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[6],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)


Marginal.prob<-data.frame(Marginal.prob)
for (k in 3:ncol(Marginal.prob)) {
Marginal.prob[,k]<-as.numeric(levels(Marginal.prob[,k]))[Marginal.prob[,k]]
}
names(Marginal.prob)<-c("Dep.Variable", "Covariate", "Mean","Lo.CI", "Hi.CI")
Marginal.prob[,3:5]<-100*Marginal.prob[,3:5]

Marginal.prob.Figure2<-Marginal.prob[c(2,3,5,7:14,
				16,17,19,21:28),]

## Reorder this based on our final definition of vars
Marginal.prob.Figure2$Covariate<- factor(Marginal.prob.Figure2$Covariate, 
			levels = rev(c("Seat.Shares","Votes","Polarization",
				"Finance", "EU.Parliament","Regional",
				 "Government","efNPP","Electoral.Coalition",
				"Organisation", "NewFamFirst")),
			labels=rev(c("Seat Share", "Electoral Performance", "Electoral Polarization",
			"State Funding", "EP Access", "Regional Government",
			"National Government", "Coalition Potential",
			"Electoral Coalition",
			"Societal Rootedness", "Ideological Novelty")))

ggplot(Marginal.prob.Figure2,
 aes(y=Covariate, x=Mean)) + 
    geom_errorbarh(aes(xmin=Lo.CI, 
	xmax=Hi.CI, height=.2), size=1,colour="black") + facet_wrap(~Dep.Variable)+
    geom_point(size=3)+scale_x_continuous(limits = c(-3, 4))+
theme_bw()+xlab("Change in death-specific hazards")+ylab("")+
geom_hline(yintercept=0, linetype="longdash", colour="gray40")+
theme(strip.text.x = element_text(size = 12, face="bold"))+
geom_vline(xintercept=0, linetype="longdash", colour="gray40")+
theme(axis.text.y = element_text(size=12)) +
 theme(axis.title=element_text(size=12))



rm(list=ls())
########################## FIGURE 3  #####################################################################################################################################################################################################
# First need to estimate the model
# Then use parameter estimates to create the figure

df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))

df$years.centered<-(df$year_exist-mean(df$year_exist))/(2*sd(df$year_exist))
df$years.centered.squared<-df$years.centered^2
df$years.centered.squared.bis<-(df$year_exist^2-mean(df$year_exist^2))/(2*sd(df$year_exist^2,na.rm=TRUE))

df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"years.centered","year_exist",
		"years.centered.squared", "years.centered.squared.bis"))
df<-na.exclude(df)


country<-as.numeric(factor(df$country.id), levels=unique(df$country.id))
party<-as.numeric(factor(df$party.id), levels=unique(df$party.id))
num.country<-length(unique(country))
num.party<-length(unique(party))

# 1= survive, 2=merge, 3=dissolve
Y<-cbind(df$merged, df$dissolved)
Y<-cbind(ifelse(rowSums(Y)==0,1,0),Y)
y<-c(sapply(1:nrow(Y), function(i) which(Y[i,]==1)))
n<-length(y)          # Number of obs
K<-3			    # Number of outcomes


Matrix.Country<-as.spam(matrix(0,n,num.country))
for (i in 1:num.country) Matrix.Country[country==i,i]<-1

Matrix.Party<-as.spam(matrix(0,n,num.party))
for (i in 1:num.party) Matrix.Party[party==i,i]<-1

X.Merge<-cbind(1,  df$years.centered, df$years.centered.squared,
	df$organisation, I(df$years.centered*df$organisation), I(df$years.centered.squared*df$organisation),
       df$newfamfirst,I(df$years.centered*df$newfamfirst), I(df$years.centered.squared*df$newfamfirst),
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,I(df$years.centered*df$finance_party_qualify), I(df$years.centered.squared*df$finance_party_qualify),
		df$election_year_dummy,
		df$indPOL, df$efNPP, 
		df$elec_coalition, 
		df$votes.history.centered,
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)


colnames(X.Merge)<-c("Intercept", "Party.Life.Length", "Party.Life.Length.Squared",
		"Social Rootedness", "Interaction:Social Rootedness-Duration", "Interaction:Social Rootedness-Duration.Squared",
		"New Family","Interaction:New Family-Duration", "Interaction:New Family-Duration.Squared",
		  "DM","DM.squared",
		"Finance",  "Interaction:Finance-Duration", "Interaction:Finance-Duration.Squared",
		"Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament",  "Regional.Government")


X.Dissolution<-cbind(1,  df$years.centered, df$years.centered.squared,
	df$organisation, I(df$years.centered*df$organisation), I(df$years.centered.squared*df$organisation),
       df$newfamfirst,I(df$years.centered*df$newfamfirst), I(df$years.centered.squared*df$newfamfirst),
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,
		df$election_year_dummy,
		df$indPOL, df$efNPP, 
		df$elec_coalition, 
		df$votes.history.centered,
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)

colnames(X.Dissolution)<-c("Intercept", "Party.Life.Length", "Party.Life.Length.Squared",
		"Social Rootedness", "Interaction:Social Rootedness-Duration", "Interaction:Social Rootedness-Duration.Squared",
		"New Family","Interaction:New Family-Duration", "Interaction:New Family-Duration.Squared",
		  "DM","DM.squared",
		"Finance", 
		"Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament","Regional.Government")

# Iterations &  burn-in
 nsim<-3000000				# Number of MCMC Iterations
 thin<-100                          # Thinning Interval (should be a divisor of nsim/2)
 burn<-250000                       # Burn-in
 lastit<-(nsim-burn)/thin	      # Last stored value

# Priors
set.seed(26135)
mu0.Merge<-rep(0,ncol(X.Merge))
Tau0.Merge<-diag(1,ncol(X.Merge))
Sigma0.Merge<-solve(Tau0.Merge)

mu0.Dissolution<-rep(0,ncol(X.Dissolution))
Tau0.Dissolution<-diag(1,ncol(X.Dissolution))
Sigma0.Dissolution<-solve(Tau0.Dissolution)

# Store Values
Beta3<-array(0,c(lastit,ncol(X.Dissolution),3)) 
Beta2<-array(0,c(lastit,ncol(X.Merge),3)) 
 Sigma.country<-array(0, c(lastit,4,3))
 Sigma.party<-array(0, c(lastit,4,3))
 Reffect.country<-array(0,c(lastit,num.country*2,3))
 Reffect.party<-array(0,c(lastit,num.party*2,3))


for (ch in 1:3) {


# Inits
 b2<-rep(0,ncol(X.Merge))
  b3<-rep(0,ncol(X.Dissolution))
  cov2<-0.01*diag(ncol(X.Merge))
  cov3<-0.01*diag(ncol(X.Dissolution))
  reffect.country<-matrix(0, num.country,2) 
  sigma.country<-diag(2)
   reffect.party<-matrix(0, num.party,2) 
  sigma.party<-diag(2)
 

A<-0

for (i in 1:nsim) {
 # Calculate Likelihood based on old value of b2 and b3
  eta2<-X.Merge%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3<-X.Dissolution%*%b3+reffect.country[country,2]+reffect.party[party,2]

  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lold<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))

 # Draw Candidates
  b2new<-b2 + rmvt(1,sigma=.005*cov2,3)  # Tuning parameter to reach appropriate acceptance rate	
  b3new<-b3 + rmvt(1,sigma=.005*cov3,3)   	

 eta2<-X.Merge%*%c(b2new)+reffect.country[country,1]+reffect.party[party,1]
  eta3<-X.Dissolution%*%c(b3new)+reffect.country[country,2]+reffect.party[party,2]
  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lnew<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))


# Acceptance prob on log scale
   r<-lnew+dmvnorm(b2new,mu0.Merge,Sigma0.Merge,log=T)+dmvnorm(b3new,mu0.Dissolution,Sigma0.Dissolution,log=T)-	
	(lold+dmvnorm(b2,mu0.Merge,Sigma0.Merge,log=T)+dmvnorm(b3,mu0.Dissolution,Sigma0.Dissolution,log=T))
   if(!is.na(r) & log(runif(1))<r){
    b2<-c(b2new)
    b3<-c(b3new)  
    A<-A+1
    }


###################################
# Update Country reffects using MH #
 ##################################
 reffect.country.new<-reffect.country+rmvt(num.country,sigma=0.001*diag(2),3) 
  eta2.old<-X.Merge%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3.old<-X.Dissolution%*%b3+reffect.country[country,2]+reffect.party[party,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X.Merge%*%b2+reffect.country.new[country,1]+reffect.party[party,1]
 eta3.new<-X.Dissolution%*%b3+reffect.country.new[country,2]+reffect.party[party,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Country)%*%(l.new-l.old)) + 
	dmvnorm(reffect.country.new,rep(0,2),sigma.country, log=TRUE)-
	dmvnorm(reffect.country,rep(0,2),sigma.country, log=TRUE)
 if (!is.na(sum(ratio))) {
u<-(log(runif(num.country))<  ratio)*1
  reffect.country[!is.na(u) & u==1,]<-reffect.country.new[!is.na(u) & u==1,]
   reffect.country[,1]<-reffect.country[,1]-mean(reffect.country[,1])
   reffect.country[,2]<-reffect.country[,2]-mean(reffect.country[,2])

 ########################
 # Update sigma.country #
 #########################
sigma.country<-riwish(num.country+3, .01*diag(2)+crossprod(reffect.country))
}    

###################################
# Update Party reffects using MH #
 ##################################
 reffect.party.new<-reffect.party+rmvt(num.party,sigma=0.001*diag(2),3) 
  eta2.old<-X.Merge%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3.old<-X.Dissolution%*%b3+reffect.country[country,2]+reffect.party[party,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X.Merge%*%b2+reffect.country[country,1]+reffect.party.new[party,1]
 eta3.new<-X.Dissolution%*%b3+reffect.country[country,2]+reffect.party.new[party,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Party)%*%(l.new-l.old)) + 
	dmvnorm(reffect.party.new,rep(0,2),sigma.party, log=TRUE)-
	dmvnorm(reffect.party,rep(0,2),sigma.party, log=TRUE)
 if (!is.na(sum(ratio))) {
 u<-(log(runif(num.party))<  ratio)*1
  reffect.party[!is.na(u) & u==1,]<-reffect.party.new[!is.na(u) & u==1,]
   reffect.party[,1]<-reffect.party[,1]-mean(reffect.party[,1])
   reffect.party[,2]<-reffect.party[,2]-mean(reffect.party[,2])

 ########################
 # Update sigma.party #
 #########################
sigma.party<-riwish(num.party+3, .01*diag(2)+crossprod(reffect.party))
}    
  
# Store Results
  if (i> burn & i%%thin==0) {
    j<-(i-burn)/thin
   Beta2[j,,ch]<-b2
   Beta3[j,,ch]<-b3
   Sigma.country[j,,ch]<-c(sigma.country)
   Reffect.country[j,,ch]<-as.vector(reffect.country)
   Sigma.party[j,,ch]<-c(sigma.party)
   Reffect.party[j,,ch]<-as.vector(reffect.party)
}

if (i%%1000==0)  print(c(ch, i, A/i))


# Backup saving (if something goes wrong)
if (i==nsim) {

Results<-list(Beta2=Beta2[,,ch], Beta3=Beta3[,,ch], 
			Sigma.country=Sigma.country[,,ch], 
			Reffect.country=Reffect.country[,,ch],
			Sigma.party=Sigma.party[,,ch], 
			Reffect.party=Reffect.party[,,ch],
			vars.Merge=colnames(X.Merge),
			vars.Dissolution=colnames(X.Dissolution))

save(Results, file=paste("Model Dynamic, chain=", ch))
}

}

} 
# End of MCMC algorithm


## Convergence checks
BETA2<-mcmc.list(as.mcmc(Beta2[,,1]), as.mcmc(Beta2[,,2]), 
		as.mcmc(Beta2[,,3]))
BETA3<-mcmc.list(as.mcmc(Beta3[,,1]), as.mcmc(Beta3[,,2]), 
		as.mcmc(Beta3[,,3]))
SIGMA.COUNTRY<-mcmc.list(as.mcmc(Sigma.country[,-3,1]), 
as.mcmc(Sigma.country[,-3,2]), as.mcmc(Sigma.country[,-3,3]))
SIGMA.PARTY<-mcmc.list(as.mcmc(Sigma.party[,-3,1]),
	 as.mcmc(Sigma.party[,-3,2]), as.mcmc(Sigma.party[,-3,3]))

gelman.diag(BETA2)[[2]]<1.2
gelman.diag(BETA3)[[2]]<1.2
gelman.diag(SIGMA.COUNTRY)[[2]]<1.2
gelman.diag(SIGMA.PARTY)[[2]]<1.2

All.Results<-list(Beta2=Beta2, Beta3=Beta3, 
			Sigma.country=Sigma.country, 
			Reffect.country=Reffect.country,
			Sigma.party=Sigma.party, 
			Reffect.party=Reffect.party,
			vars.dissolution=colnames(X.Dissolution),
			vars.merger=colnames(X.Merge))


Beta.2<-rbind(All.Results$Beta2[27251:27500,,1], All.Results$Beta2[27251:27500,,2], All.Results$Beta2[27251:27500,,3])
Beta.3<-rbind(All.Results$Beta3[27251:27500,,1], All.Results$Beta3[27251:27500,,2], All.Results$Beta3[27251:27500,,3])


df$years<-(df$year_exist-mean(df$year_exist))/(2*sd(df$year_exist))
df$years.squared<-df$year_exist^2
df$years.squared<-(df$years.squared-mean(df$years.squared))/(2*sd(df$years.squared))

x<-cbind(1,unique(df$years), unique(df$years.squared))
Dynamic.Finance.Mergers<-c()
for (s in 1:nrow(x)){
Dynamic.Finance.Mergers<-rbind(Dynamic.Finance.Mergers,
c(s,
mean(Beta.2[,12:14]%*%matrix(x[s,])),HPDinterval(as.mcmc(Beta.2[,12:14]%*%matrix(x[s,])), p=0.9))
)
}
Dynamic.Finance.Mergers<-data.frame(Dynamic.Finance.Mergers)
names(Dynamic.Finance.Mergers)<-c("x", "y", "lower", "upper")


g1 <- ggplot(Dynamic.Finance.Mergers) + geom_line(aes(y=y, x=x))+
  stat_smooth(aes(x = x, y = lower, colour = "min"), method = "loess", se = FALSE) +
  stat_smooth(aes(x = x, y = upper, colour = "max"), method = "loess", se = FALSE)
gg1 <- ggplot_build(g1)

df2 <- data.frame(x = gg1$data[[2]]$x,
                  ymin = gg1$data[[2]]$y,
                  ymax = gg1$data[[3]]$y) 


# use the loess data to add the 'ribbon' to plot 
g1 +
  geom_ribbon(data = df2, aes(x = x, ymin = ymin, ymax = ymax),
              fill = "grey", alpha = 0.4)+
 xlab("Party Age (in years)")+ylab("Log-hazard of party death")+
	#ggtitle("Influence of State Funding on the Risk of Party Merger")+
	theme_bw()+
	geom_hline(yintercept=0, linetype="dashed")+
	 theme(legend.position="none")+
	scale_x_continuous(limits = c(1, 47),
	breaks = c(1,5,10,15,20,25,30,35,40,45),
	labels=seq(0,45,by=5))


########################## FIGURE 4  #####################################################################################################################################################################################################
# Builds on the previous model

df$years<-(df$year_exist-mean(df$year_exist))/(2*sd(df$year_exist))
df$years.squared<-df$year_exist^2
df$years.squared<-(df$years.squared-mean(df$years.squared))/(2*sd(df$years.squared))
x<-cbind(1,unique(df$years), unique(df$years.squared))

Dynamic.Organization.Merger<-c()
Dynamic.Organization.Dissolution<-c()
Dynamic.Family.Merger<-c()
Dynamic.Family.Dissolution<-c()



for (s in 1:nrow(x)){
Dynamic.Organization.Merger<-rbind(Dynamic.Organization.Merger,
c(s,
mean(Beta.2[,4:6]%*%matrix(x[s,])),HPDinterval(as.mcmc(Beta.2[,4:6]%*%matrix(x[s,])), p=0.9))
)
}

for (s in 1:nrow(x)){
Dynamic.Organization.Dissolution<-rbind(Dynamic.Organization.Dissolution,
c(s,
mean(Beta.3[,4:6]%*%matrix(x[s,])),HPDinterval(as.mcmc(Beta.3[,4:6]%*%matrix(x[s,])), p=0.9))
)
}


for (s in 1:nrow(x)){
Dynamic.Family.Merger<-rbind(Dynamic.Family.Merger,
c(s,
mean(Beta.2[,7:9]%*%matrix(x[s,])),HPDinterval(as.mcmc(Beta.2[,7:9]%*%matrix(x[s,])), p=0.9))
)
}


for (s in 1:nrow(x)){
Dynamic.Family.Dissolution<-rbind(Dynamic.Family.Dissolution,
c(s,
mean(Beta.3[,7:9]%*%matrix(x[s,])),HPDinterval(as.mcmc(Beta.3[,7:9]%*%matrix(x[s,])), p=0.9))
)
}

Dynamics<-rbind(
cbind(Dynamic.Organization.Dissolution,"Societal Rootedness", "Dissolution"),
cbind(Dynamic.Organization.Merger,"Societal Rootedness", "Merger"),
cbind(Dynamic.Family.Dissolution,"Ideological Novelty", "Dissolution"),
cbind(Dynamic.Family.Merger,"Ideological Novelty", "Merger")
)

Dynamics<-data.frame(Dynamics)
names(Dynamics)<-c("x", "y", "lower", "upper", "Variable", "Death")

for (k in 1:4) {
Dynamics[,k]<- as.numeric(levels(Dynamics[,k]))[Dynamics[,k]]
}

Dynamics$Variable<-factor(Dynamics$Variable,
			levels = c("Societal Rootedness", 
					"Ideological Novelty"))


d1<-subset(Dynamics, Variable=="Societal Rootedness" &
	     Death=="Dissolution")
d2<-subset(Dynamics, Variable=="Societal Rootedness" &
	     Death=="Merger")
d3<-subset(Dynamics, Variable=="Ideological Novelty" &
	     Death=="Dissolution")
d4<-subset(Dynamics, Variable=="Ideological Novelty" &
	     Death=="Merger")


p<-ggplot(Dynamics) + geom_line(aes(y=y, x=x))+ 
  stat_smooth(aes(x = x, y = lower, colour = "grey12"), method = "loess", se = FALSE) +
  stat_smooth(aes(x = x, y = upper, colour = "grey12"), method = "loess", se = FALSE)+
  facet_grid(Variable ~ Death)

g1 <- ggplot(d1) + 
  stat_smooth(aes(x = x, y = lower, colour = "min"), method = "loess", se = FALSE) +
  stat_smooth(aes(x = x, y = upper, colour = "max"), method = "loess", se = FALSE)

gg1 <- ggplot_build(g1)

dd1 <- data.frame(x = gg1$data[[1]]$x,
                  ymin = gg1$data[[1]]$y,
                  ymax = gg1$data[[2]]$y) 



g2 <- ggplot(d2) + 
  stat_smooth(aes(x = x, y = lower, colour = "min"), method = "loess", se = FALSE) +
  stat_smooth(aes(x = x, y = upper, colour = "max"), method = "loess", se = FALSE)

gg2 <- ggplot_build(g2)

dd2 <- data.frame(x = gg2$data[[1]]$x,
                  ymin = gg2$data[[1]]$y,
                  ymax = gg2$data[[2]]$y) 

g3 <- ggplot(d3) + 
  stat_smooth(aes(x = x, y = lower, colour = "min"), method = "loess", se = FALSE) +
  stat_smooth(aes(x = x, y = upper, colour = "max"), method = "loess", se = FALSE)
gg3 <- ggplot_build(g3)

dd3 <- data.frame(x = gg3$data[[1]]$x,
                  ymin = gg3$data[[1]]$y,
                  ymax = gg3$data[[2]]$y) 

g4 <- ggplot(d4) + 
  stat_smooth(aes(x = x, y = lower, colour = "min"), method = "loess", se = FALSE) +
  stat_smooth(aes(x = x, y = upper, colour = "max"), method = "loess", se = FALSE)
gg4 <- ggplot_build(g4)

dd4 <- data.frame(x = gg4$data[[1]]$x,
                  ymin = gg4$data[[1]]$y,
                  ymax = gg4$data[[2]]$y) 

dd1$Variable<-"Societal Rootedness"
dd1$Death<-"Dissolution"
dd2$Variable<-"Societal Rootedness"
dd2$Death<-"Merger"
dd3$Variable<-"Ideological Novelty"
dd3$Death<-"Dissolution"
dd4$Variable<-"Ideological Novelty"
dd4$Death<-"Merger"


dd<-rbind(dd1,dd2,dd3,dd4)

dd$Variable<-factor(dd$Variable,
			levels = c("Societal Rootedness", 
					"Ideological Novelty"))


p<-p+
  geom_ribbon(data = dd, aes(x = x, ymin = ymin, ymax = ymax),
              fill = "grey", alpha = 0.4)+
xlab("Party Age (in years)")+ylab("Log-hazard of party death")+
	facet_grid(Variable ~ Death)+
	geom_hline(yintercept=0, linetype="dashed")+
	theme_bw()+
	 theme(legend.position="none")+
	scale_x_continuous(limits = c(1, 47),
	breaks = c(1,5,10,15,20,25,30,35,40,45),
	labels=seq(0,45,by=5))+
	theme(strip.text.x = element_text(size=12, face="bold"),
          strip.text.y = element_text(size=12, face="bold"))

p


rm(list=ls())
########################## FIGURE A.1 (ONLINE APPENDIX) #####################################################################################################################################################################################################
df<-read.csv("data.survival.csv")

# Multiple plot function
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)

  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)

  numPlots = length(plots)

  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                    ncol = cols, nrow = ceiling(numPlots/cols))
  }

 if (numPlots==1) {
    print(plots[[1]])

  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))

    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))

      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}


df.Numparties<-c()
for (i in 1:length(unique(df$country))) {
df.Numparties<-rbind(df.Numparties,
c(as.character(unique(df$country)[i]),length(unique(df$party.id[df$country==unique(df$country)[i]])))
)
}
df.Numparties<-data.frame(df.Numparties)
names(df.Numparties)<-c("Country", "Parties")
df.Numparties[,2]<-as.numeric(levels(df.Numparties[,2]))[df.Numparties[,2]]


df.Numparties$Country<-factor(df.Numparties$Country, levels=c("UK","Switzerland",
	"Sweden", "Spain", "Portugal", "Norway", "New Zealand",
	"Netherlands", "Luxembourg", "Ireland", "Iceland",
	"Greece", "Germany", "France", "Finland", "Denmark",
	"Cyprus", "Canada", "Belgium", "Austria", "Australia"))

p2<-ggplot(df.Numparties,aes(x=Country,y=Parties))+
  geom_bar(stat="identity", fill="gray")+theme_bw()+xlab("")+
	ggtitle("Number of parties")+
	coord_flip()+ylab("")+
	theme(plot.title = element_text(hjust = 0.5))

df.Age<-c()
for (i in 1:length(unique(df$country))) {
dd<-subset(df, country==unique(df$country)[i])
age<-by(dd$year_exist, dd$party.id,max)
df.Age<-rbind(df.Age,
c(as.character(unique(dd$country)), quantile(age, 0.25, na.rm=TRUE),
quantile(age, 0.75, na.rm=TRUE),
median(age, na.rm=TRUE),
quantile(age, 0.1, na.rm=TRUE),
quantile(age, 0.9, na.rm=TRUE))
)
}

df.Age<-data.frame(df.Age)
names(df.Age)<-c("Country", "lower", "upper", "middle", "ymin", "ymax")
for (k in 2:ncol(df.Age)) {
df.Age[,k]<-as.numeric(levels(df.Age[,k]))[df.Age[,k]]
}

df.Age$Country<-factor(df.Age$Country, levels=c("UK","Switzerland",
	"Sweden", "Spain", "Portugal", "Norway", "New Zealand",
	"Netherlands", "Luxembourg", "Ireland", "Iceland",
	"Greece", "Germany", "France", "Finland", "Denmark",
	"Cyprus", "Canada", "Belgium", "Austria", "Australia"))

p3 <- ggplot(df.Age, aes(x=Country, lower=lower, upper=upper, middle=middle, ymin=ymin, ymax=ymax)) + 
geom_boxplot(stat="identity", outlier.shape=NA, fill="gray80")+theme_bw()+
xlab("")+ggtitle("Party Life Length")+
theme(axis.title.y=element_text(vjust=1.25),
axis.title.x=element_text(vjust=-.35))+
ylab("Years")+	theme(plot.title = element_text(hjust = 0.5))+
coord_flip()


multiplot(p2, p3, cols=2)


rm(list=ls())
########################## FIGURE A.2 (ONLINE APPENDIX) #####################################################################################################################################################################################################
df<-read.csv("data.survival.csv")

df.Votes<-c()

for (i in 1:length(unique(df$country))) {
df.Votes<-rbind(df.Votes, c(as.character(unique(df$country)[i]),
quantile(df$votes[df$country==unique(df$country)[i]], 0.25, na.rm=TRUE),
quantile(df$votes[df$country==unique(df$country)[i]], 0.75, na.rm=TRUE),
median(df$votes[df$country==unique(df$country)[i]], na.rm=TRUE),
quantile(df$votes[df$country==unique(df$country)[i]], 0.1, na.rm=TRUE),
quantile(df$votes[df$country==unique(df$country)[i]], 0.9, na.rm=TRUE)
)
)
}

df.Votes<-data.frame(df.Votes)
names(df.Votes)<-c("Country", "lower", "upper", "middle", "ymin", "ymax")
for (k in 2:ncol(df.Votes)) {
df.Votes[,k]<-as.numeric(levels(df.Votes[,k]))[df.Votes[,k]]
}


ggplot(df.Votes, aes(x=Country, lower=lower, upper=upper, middle=middle, ymin=ymin, ymax=ymax)) + 
geom_boxplot(stat="identity", outlier.shape=NA, fill="gray80")+theme_bw()+
xlab("")+#ggtitle("Distribtuion of vote-shares for the parties in the sample")+
theme(axis.title.y=element_text(vjust=1.25),
axis.title.x=element_text(vjust=-.35))+
ylab("%")+ theme(axis.text.x = element_text(angle = 90, vjust=0.4, hjust=1))


rm(list=ls())
########################## FIGURE A.3 (ONLINE APPENDIX) #####################################################################################################################################################################################################

df<-read.csv("data.survival.csv")

Joint<-rbind(cbind(rownames(by(df$merged, df$country,sum)),
by(df$merged, df$country,sum), "Mergers"),
cbind(rownames(by(df$merged, df$country,sum)),
by(df$dissolved, df$country,sum), "Dissolutions"))
Joint<-data.frame(Joint)
names(Joint)<-c("Country", "Death", "Type")
Joint$Death<- as.numeric(levels(Joint$Death))[Joint$Death]
Joint$Country<-factor(Joint$Country, levels=c("UK","Switzerland",
	"Sweden", "Spain", "Portugal", "Norway", "New Zealand",
	"Netherlands", "Luxembourg", "Ireland", "Iceland",
	"Greece", "Germany", "France", "Finland", "Denmark",
	"Cyprus", "Canada", "Belgium", "Austria", "Australia"))


ggplot(Joint,aes(x=Country,y=Death))+
  geom_bar(stat="identity", fill="gray")+theme_bw()+xlab("")+
	scale_y_continuous(limits=c(0,8))+
	facet_wrap(~ Type)+coord_flip()+ylab("Number of Party Deaths")+
theme(strip.text.x = element_text(size = 12, face="bold"))


rm(list=ls())

########################## TABLE A.1 (ONLINE APPENDIX) #####################################################################################################################################################################################################

df<-read.csv("data.survival.csv")

rnd = function(x, n) {
  posneg = sign(x)
  z = abs(x)*10^n
  z = z + 0.5
  z = trunc(z)
  z = z/10^n
  z*posneg
}

## Summary stats for variables used in the analysis

## Dissolution
rnd(mean(df$dissolved),2)
rnd(sd(df$dissolved),2)
rnd(range(df$dissolved),2)

## Merger
rnd(mean(df$merged),2)
rnd(sd(df$merged),2)
rnd(range(df$merged),2)

## Seat Share
rnd(mean(df$log.seats),2)
rnd(sd(df$log.seats),2)
rnd(range(df$log.seats),2)

## Electoral Performance
rnd(mean(df$votes.history.centered, na.rm=T),2)
rnd(sd(df$votes.history.centered, na.rm=T),2)
rnd(range(df$votes.history.centered, na.rm=T),2)

# State Funding
rnd(mean(df$finance),2)
rnd(sd(df$finance),2)
rnd(range(df$finance),2)

# EP Access
rnd(mean(df$EU_parl),2)
rnd(sd(df$EU_parl),2)
rnd(range(df$EU_parl),2)

# Regional Government
rnd(mean(df$reg_gov.lagged),2)
rnd(sd(df$reg_gov.lagged),2)
rnd(range(df$reg_gov.lagged),2)

#National Government
rnd(mean(df$government),2)
rnd(sd(df$government),2)
rnd(range(df$government),2)

# Electoral Coalition
rnd(mean(df$elec_coalition),2)
rnd(sd(df$elec_coalition),2)
rnd(range(df$elec_coalition),2)

# Social Rootedness
rnd(mean(df$organisation),2)
rnd(sd(df$organisation),2)
rnd(range(df$organisation),2)


# Ideological Novelty 
rnd(mean(df$newfamfirst),2)
rnd(sd(df$newfamfirst),2)
rnd(range(df$newfamfirst),2)

# Party Age
rnd(mean(by(df$year_exist, df$case_id, max)),2)
rnd(sd(by(df$year_exist, df$case_id, max)),2)
rnd(range(by(df$year_exist, df$case_id, max)),2)

#Electoral Polarization
rnd(mean(df$indPOL),2)
rnd(sd(df$indPOL),2)
rnd(range(df$indPOL),2)

#Coalition Potential
rnd(mean(df$efNPP),2)
rnd(sd(df$efNPP),2)
rnd(range(df$efNPP),2)

#District Magnitude
rnd(mean(df$dm),2)
rnd(sd(df$dm),2)
rnd(range(df$dm),2)

# Election Year
rnd(mean(df$election_year_dummy),2)
rnd(sd(df$election_year_dummy),2)
rnd(range(df$election_year_dummy),2)


rm(list=ls())
########################## TABLE A.2 (ONLINE APPENDIX) #####################################################################################################################################################################################################
library(psych)
library(usdm)
library(ltm)
library(perturb)

df<-read.csv("data.survival.csv")
df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))

dd<-df[,c(54,42,19,29, 46, 20,34,12,15,8,33,32,21,9)]
names(dd)<-c( "Seat.Share","Electoral.Performance",
		"State.Funding", "EP.Access", 
		"Regional.Government", "National.Government",
		"Electoral.Coalition", "Societal.Rootedness",
		"Ideological.Novelty", "Party.Age", "Electoral.Polarization",
		"Coalition.Potential", "District.Magnitude", "Election.Year")

# VIF and correlations
cbind(names(dd),round(vif(dd)[,2],digits=2))

mixed.cor(dd)



########################## TABLE A.3 (ONLINE APPENDIX) #####################################################################################################################################################################################################

cbind(names(dd),round(matrix(colldiag(dd)$condindx[-1]),digits=2))



rm(list=ls())
########################## TABLE A.4 (ONLINE APPENDIX) #####################################################################################################################################################################################################
df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))

df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"log.partyyears"))
df<-na.exclude(df)



country<-as.numeric(factor(df$country.id), levels=unique(df$country.id))
party<-as.numeric(factor(df$party.id), levels=unique(df$party.id))
num.country<-length(unique(country))
num.party<-length(unique(party))

# 1= survive, 2=merge, 3=dissolve
Y<-cbind(df$merged, df$dissolved)
Y<-cbind(ifelse(rowSums(Y)==0,1,0),Y)
y<-c(sapply(1:nrow(Y), function(i) which(Y[i,]==1)))
n<-length(y)          # Number of obs
K<-3			    # Number of outcomes


Matrix.Country<-as.spam(matrix(0,n,num.country))
for (i in 1:num.country) Matrix.Country[country==i,i]<-1

Matrix.Party<-as.spam(matrix(0,n,num.party))
for (i in 1:num.party) Matrix.Party[party==i,i]<-1


X<-cbind(1,  df$log.partyyears, df$organisation, df$newfamfirst,
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,df$election_year_dummy,
		df$indPOL, df$efNPP,  
		df$elec_coalition, 
		df$votes.history.centered, 
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)

colnames(X)<-c("Intercept", "Party.Life.Length", "Organisation", "NewFamFirst",
		  "DM","DM.squared", "Finance", "Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament", "Regional")


# Iterations &  burn-in
 nsim<-3000000				# Number of MCMC Iterations
 thin<-100                          # Thinning Interval (should be a divisor of nsim/2)
 burn<-250000                       # Burn-in
 lastit<-(nsim-burn)/thin	      # Last stored value

# Priors
set.seed(115512)
mu0<-rep(0,ncol(X))
Tau0<-diag(1,ncol(X))
Sigma0<-solve(Tau0)

# Store Values
 Beta2<-Beta3<-array(0,c(lastit,ncol(X),3)) 
 Sigma.country<-array(0, c(lastit,4,3))
 Sigma.party<-array(0, c(lastit,4,3))
 Reffect.country<-array(0,c(lastit,num.country*2,3))
 Reffect.party<-array(0,c(lastit,num.party*2,3))

for (ch in 1:3) {

# Inits
  b2<-rep(0,ncol(X))
  b3<-rep(0,ncol(X))
  cov2<-cov3<-0.01*diag(ncol(X))
  reffect.country<-matrix(0, num.country,2) 
  sigma.country<-diag(2)
   reffect.party<-matrix(0, num.party,2) 
  sigma.party<-diag(2)
 

A<-0

for (i in 1:nsim) {
 # Calculate Likelihood based on old value of b2 and b3
  eta2<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]

  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lold<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))

 # Draw Candidates
  b2new<-b2 + rmvt(1,sigma=.005*cov2,3)  # Tuning parameter to reach appropriate acceptance rate	
  b3new<-b3 + rmvt(1,sigma=.005*cov3,3)   	

 eta2<-X%*%c(b2new)+reffect.country[country,1]+reffect.party[party,1]
  eta3<-X%*%c(b3new)+reffect.country[country,2]+reffect.party[party,2]
  p1<-1/(1+exp(eta2)+exp(eta3))
  p2<-p1*exp(eta2)
  p3<-p1*exp(eta3)
  lnew<-sum(log(p1)*(y==1)+log(p2)*(y==2)+log(p3)*(y==3))


# Acceptance prob on log scale
   r<-lnew+dmvnorm(b2new,mu0,Sigma0,log=T)+dmvnorm(b3new,mu0,Sigma0,log=T)-	
	(lold+dmvnorm(b2,mu0,Sigma0,log=T)+dmvnorm(b3,mu0,Sigma0,log=T))
   if(log(runif(1))<r){
    b2<-c(b2new)
    b3<-c(b3new)  
    A<-A+1
    }


###################################
# Update Country reffects using MH #
 ##################################
 reffect.country.new<-reffect.country+rmvt(num.country,sigma=0.001*diag(2),3) 
  eta2.old<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3.old<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X%*%b2+reffect.country.new[country,1]+reffect.party[party,1]
 eta3.new<-X%*%b3+reffect.country.new[country,2]+reffect.party[party,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Country)%*%(l.new-l.old)) + 
	dmvnorm(reffect.country.new,rep(0,2),sigma.country, log=TRUE)-
	dmvnorm(reffect.country,rep(0,2),sigma.country, log=TRUE)
 u<-(log(runif(num.country))<  ratio)*1
  reffect.country[!is.na(u) & u==1,]<-reffect.country.new[!is.na(u) & u==1,]
   reffect.country[,1]<-reffect.country[,1]-mean(reffect.country[,1])
   reffect.country[,2]<-reffect.country[,2]-mean(reffect.country[,2])

 ########################
 # Update sigma.country #
 #########################
sigma.country<-riwish(num.country+3, .01*diag(2)+crossprod(reffect.country))
    

###################################
# Update Party reffects using MH #
 ##################################
 reffect.party.new<-reffect.party+rmvt(num.party,sigma=0.001*diag(2),3) 
  eta2.old<-X%*%b2+reffect.country[country,1]+reffect.party[party,1]
  eta3.old<-X%*%b3+reffect.country[country,2]+reffect.party[party,2]
  p1.old<-1/(1+exp(eta2.old)+exp(eta3.old))
  p2.old<-p1.old*exp(eta2.old)
  p3.old<-p1.old*exp(eta3.old)
 l.old<-log(p1.old)*(y==1)+log(p2.old)*(y==2)+log(p3.old)*(y==3)
 eta2.new<-X%*%b2+reffect.country[country,1]+reffect.party.new[party,1]
 eta3.new<-X%*%b3+reffect.country[country,2]+reffect.party.new[party,2]
  p1.new<-1/(1+exp(eta2.new)+exp(eta3.new))
  p2.new<-p1.new*exp(eta2.new)
  p3.new<-p1.new*exp(eta3.new)
 l.new<-log(p1.new)*(y==1)+log(p2.new)*(y==2)+log(p3.new)*(y==3)
 ratio<-(t(Matrix.Party)%*%(l.new-l.old)) + 
	dmvnorm(reffect.party.new,rep(0,2),sigma.party, log=TRUE)-
	dmvnorm(reffect.party,rep(0,2),sigma.party, log=TRUE)
 u<-(log(runif(num.party))<  ratio)*1
  reffect.party[!is.na(u) & u==1,]<-reffect.party.new[!is.na(u) & u==1,]
   reffect.party[,1]<-reffect.party[,1]-mean(reffect.party[,1])
   reffect.party[,2]<-reffect.party[,2]-mean(reffect.party[,2])

 ########################
 # Update sigma.party #
 #########################
sigma.party<-riwish(num.party+3, .01*diag(2)+crossprod(reffect.party))
    
  
# Store Results
  if (i> burn & i%%thin==0) {
    j<-(i-burn)/thin
   Beta2[j,,ch]<-b2
   Beta3[j,,ch]<-b3
   Sigma.country[j,,ch]<-c(sigma.country)
   Reffect.country[j,,ch]<-as.vector(reffect.country)
   Sigma.party[j,,ch]<-c(sigma.party)
   Reffect.party[j,,ch]<-as.vector(reffect.party)
}


if (i%%10000==0)  print(c(ch, i, A/i))


# Backup saving (if something goes wrong)
if (i==nsim) {

Results<-list(Beta2=Beta2[,,ch], Beta3=Beta3[,,ch], 
			Sigma.country=Sigma.country[,,ch], 
			Reffect.country=Reffect.country[,,ch],
			Sigma.party=Sigma.party[,,ch], 
			Reffect.party=Reffect.party[,,ch],
			vars=colnames(X))


save(Results, file=paste("Table A.4, chain=", ch))
}

}

}# End of MCMC algorithm


## Convergence checks
BETA2<-mcmc.list(as.mcmc(Beta2[,,1]), as.mcmc(Beta2[,,2]), 
		as.mcmc(Beta2[,,3]))
BETA3<-mcmc.list(as.mcmc(Beta3[,,1]), as.mcmc(Beta3[,,2]), 
		as.mcmc(Beta3[,,3]))
SIGMA.COUNTRY<-mcmc.list(as.mcmc(Sigma.country[,-3,1]), 
as.mcmc(Sigma.country[,-3,2]), as.mcmc(Sigma.country[,-3,3]))
SIGMA.PARTY<-mcmc.list(as.mcmc(Sigma.party[,-3,1]),
	 as.mcmc(Sigma.party[,-3,2]), as.mcmc(Sigma.party[,-3,3]))

gelman.diag(BETA2)[[2]]<1.2
gelman.diag(BETA3)[[2]]<1.2
gelman.diag(SIGMA.COUNTRY)[[2]]<1.2
gelman.diag(SIGMA.PARTY)[[2]]<1.2

All.Results<-list(Beta2=Beta2, Beta3=Beta3, 
			Sigma.country=Sigma.country, 
			Reffect.country=Reffect.country,
			Sigma.party=Sigma.party, 
			Reffect.party=Reffect.party,
			vars=colnames(X))

save(All.Results, file="All.Results.TableA4")

Beta.2<-rbind(All.Results$Beta2[27201:27500,,1], All.Results$Beta2[27201:27500,,2], All.Results$Beta2[27201:27500,,3])
Beta.3<-rbind(All.Results$Beta3[27201:27500,,1], All.Results$Beta3[27201:27500,,2], All.Results$Beta3[27201:27500,,3])
colnames(Beta.2)<-All.Results$vars
colnames(Beta.3)<-All.Results$vars
Sigma.Country<-rbind(All.Results$Sigma.country[27201:27500,,1], All.Results$Sigma.country[27201:27500,,2], All.Results$Sigma.country[27201:27500,,3])
Sigma.Party<-rbind(All.Results$Sigma.party[27201:27500,,1], All.Results$Sigma.party[27201:27500,,2], All.Results$Sigma.party[27201:27500,,3])
Reffect.Country<-rbind(All.Results$Reffect.country[27201:27500,,1],All.Results$Reffect.country[27201:27500,,2], All.Results$Reffect.country[27201:27500,,3])
Reffect.Country.Merge<-Reffect.Country[,1:num.country]
Reffect.Country.Dissolution<-Reffect.Country[,(num.country+1):(2*num.country)]
Reffect.Party<-rbind(All.Results$Reffect.party[27201:27500,,1],All.Results$Reffect.party[27201:27500,,2], All.Results$Reffect.party[27201:27500,,3])
Reffect.Party.Merge<-Reffect.Party[,1:num.party]
Reffect.Party.Dissolution<-Reffect.Party[,(num.party+1):(2*num.party)]

# Column 1
Determinants.Dissolution<-round(cbind(colMeans(Beta.3),HPDinterval(as.mcmc(Beta.3), p=0.9)),digits=3)
colnames(Determinants.Dissolution)<-c("Estimate", "CI - Lower", "CI - Higher")
Determinants.Dissolution

# Column 2
Determinants.Mergers<-round(cbind(colMeans(Beta.2),HPDinterval(as.mcmc(Beta.2), p=0.9)),digits=3)
colnames(Determinants.Mergers)<-c("Estimate", "CI - Lower", "CI - Higher")
Determinants.Mergers

## Columns 1 and 2, chi-squared p-value
# Percent correctly predicted
mean.predicted.probs<-cbind(1/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])),
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])),
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])/(1+
exp(X%*%apply(Beta.3,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,2]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,2])+
exp(X%*%apply(Beta.2,2,mean)+matrix(apply(Reffect.Country,2,mean),ncol=2)[country,1]+matrix(apply(Reffect.Party,2,mean),ncol=2)[party,1])))

# Chi-squared goodness of fit test 
# H0: Data is consistent with the fitted model
observed<-sapply(1:3, function(k) sum(Y[,k]))
expected<-sapply(1:3, function(k) sum(mean.predicted.probs[,k]))/nrow(X)

chisq.test(observed, p=expected)$p.value  							#



rm(list=ls())
########################## FIGURE A.4 (ONLINE APPENDIX) #####################################################################################################################################################################################################

df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))


df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"year_exist"))
df<-na.exclude(df)

duration<-as.numeric(factor(df$year_exist), levels=unique(df$year_exist))
num.duration<-length(unique(duration))

load("All.Results.Table2.Cols34")

Reffect.Duration<-rbind(All.Results$Reffect.duration[27291:27500,,1],
		All.Results$Reffect.duration[27291:27500,,2], 
		All.Results$Reffect.duration[27291:27500,,3])
Reffect.Duration.Merge<-Reffect.Duration[,1:num.duration]
Reffect.Duration.Dissolution<-Reffect.Duration[,(num.duration+1):(2*num.duration)]

Merge<-cbind(1:47,colMeans(Reffect.Duration.Merge), HPDinterval(as.mcmc(Reffect.Duration.Merge), p=0.9))
Merge<-data.frame(Merge)
names(Merge)<-c("Year", "Estimate", "Low", "High")

Dissolution<-cbind(1:47, colMeans(Reffect.Duration.Dissolution), HPDinterval(as.mcmc(Reffect.Duration.Dissolution), p=0.9))
Dissolution<-data.frame(Dissolution)
names(Dissolution)<-c("Year", "Estimate", "Low", "High")

Death<-rbind(Dissolution, Merge)
Death<-cbind(Death,c(rep("Dissolution",47),rep("Merger", 47)))
names(Death)[dim(Death)[2]]<-"Type"


ggplot(Death, aes(x=Year, y=Estimate))+  geom_point(size=2)+
	facet_wrap(~Type)+xlab("Party Age (years)")+ylab("Log-hazard")+
	geom_errorbar(aes(ymin=Low, ymax=High))+theme_bw()+
	theme(strip.text.x = element_text(size = 12, face="bold"))+
	 geom_hline(aes(yintercept=0), colour="gray", linetype="dashed", size=2)+
	scale_x_continuous(limits = c(1, 47),
	breaks = c(1,5,10,15,20,25,30,35,40,45))


rm(list=ls())
########################## FIGURE A.5 (ONLINE APPENDIX) #####################################################################################################################################################################################################
df<-read.csv("data.survival.csv")


df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))


df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"year_exist"))
df<-na.exclude(df)



country<-as.numeric(factor(df$country.id), levels=unique(df$country.id))
party<-as.numeric(factor(df$party.id), levels=unique(df$party.id))
duration<-as.numeric(factor(df$year_exist), levels=unique(df$year_exist))
num.country<-length(unique(country))
num.party<-length(unique(party))
num.duration<-length(unique(duration))

X<-cbind(1,  df$organisation, df$newfamfirst,
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,df$election_year_dummy,
		df$indPOL, df$efNPP,  
		df$elec_coalition, 
		df$votes.history.centered, 
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)

colnames(X)<-c("Intercept", "Organisation", "NewFamFirst",
		  "DM","DM.squared", "Finance", "Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament", "Regional")



load("All.Results.Table2.Cols34")


Beta.2<-rbind(All.Results$Beta2[27291:27500,,1], All.Results$Beta2[27291:27500,,2], All.Results$Beta2[27291:27500,,3])
Beta.3<-rbind(All.Results$Beta3[27291:27500,,1], All.Results$Beta3[27291:27500,,2], All.Results$Beta3[27291:27500,,3])
colnames(Beta.2)<-All.Results$vars
colnames(Beta.3)<-All.Results$vars
Sigma.Country<-rbind(All.Results$Sigma.country[27291:27500,,1], All.Results$Sigma.country[27291:27500,,2], All.Results$Sigma.country[27291:27500,,3])
Sigma.Party<-rbind(All.Results$Sigma.party[27291:27500,,1], All.Results$Sigma.party[27291:27500,,2], All.Results$Sigma.party[27291:27500,,3])
Reffect.Country<-rbind(All.Results$Reffect.country[27291:27500,,1],All.Results$Reffect.country[27291:27500,,2], All.Results$Reffect.country[27291:27500,,3])
Reffect.Duration<-rbind(All.Results$Reffect.duration[27291:27500,,1],All.Results$Reffect.duration[27291:27500,,2], All.Results$Reffect.duration[27291:27500,,3])
Reffect.Party<-rbind(All.Results$Reffect.party[27291:27500,,1],All.Results$Reffect.party[27291:27500,,2], All.Results$Reffect.party[27291:27500,,3])

## Marginal Effects
dummies<-c(2, 3, 6,7,10,13, 14,15)
continuous<-c(8,9, 11,12)

Marginal.prob<-matrix(NA, nrow=(1+length(dummies)+length(continuous))*2, ncol=5)
colnames(Marginal.prob)<-c("Dep.Variable", "Covariate", "Predictive Comparison",  "90% CI - Lower", "90% CI - Higher")
Marginal.prob[,1]<-c(rep("Dissolution",(1+length(dummies)+length(continuous))) ,rep("Merger",(1+length(dummies)+length(continuous))))
Marginal.prob[,2]<-rep(colnames(X)[sort(c(4,dummies, continuous))],2)

for (j in dummies) {
X.0<-X
X.0[,j]<-0
X.1<-X
X.1[,j]<-1

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)
}

for (j in continuous) {
X.0<-X
X.1<-X
X.1[,j]<-X.0[,j]+sd(X[,j])

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)


Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)
}
 
# Quadrati term for DM
X.0<-X
X.1<-X
X.1[,4]<-X[,4]+sd(X[,4])
X.1[,5]<-X.1[,4]^2

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Marginal.prob[grep(colnames(X)[4],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[4],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)

Marginal.prob<-data.frame(Marginal.prob)
for (k in 3:ncol(Marginal.prob)) {
Marginal.prob[,k]<-as.numeric(levels(Marginal.prob[,k]))[Marginal.prob[,k]]
}
names(Marginal.prob)<-c("Dep.Variable", "Covariate", "Mean","Lo.CI", "Hi.CI")
Marginal.prob[,3:5]<-100*Marginal.prob[,3:5]

Marginal.prob.Figure2<-Marginal.prob[c(1:2,4,6:13,
				14:15, 17,19:26),]

Marginal.prob.Figure2$Covariate<- factor(Marginal.prob.Figure2$Covariate, 
			levels = rev(c("Seat.Shares","Votes","Polarization",
				"Finance", "EU.Parliament","Regional",
				 "Government","efNPP","Electoral.Coalition",
				"Organisation", "NewFamFirst")),
			labels=rev(c("Seat Share", "Electoral Performance", "Electoral Polarization",
			"State Funding", "EP Access", "Regional Government",
			"National Government", "Coalition Potential",
			"Electoral Coalition",
			"Societal Rootedness", "Ideological Novelty")))


## Reorder this based on our final definition of vars
ggplot(Marginal.prob.Figure2,
 aes(y=Covariate, x=Mean)) + 
    geom_errorbarh(aes(xmin=Lo.CI, 
	xmax=Hi.CI, height=.2), size=1, colour="black") + facet_wrap(~Dep.Variable)+
    geom_point(size=3)+scale_x_continuous(limits = c(-3, 3), 
	breaks=c(-3,-2,-1,0,1,2,3))+
theme_bw()+xlab("Change in death-specific hazards")+ylab("")+
geom_hline(yintercept=0, linetype="longdash", colour="gray40")+
theme(strip.text.x = element_text(size = 12, face="bold"))+
geom_vline(xintercept=0, linetype="longdash", colour="gray40")+
theme(axis.text.y = element_text(size=12)) +
 theme(axis.title=element_text(size=12))


########################## FIGURE A.6 (ONLINE APPENDIX) #####################################################################################################################################################################################################
df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))

df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"log.partyyears"))
df<-na.exclude(df)

country<-as.numeric(factor(df$country.id), levels=unique(df$country.id))
party<-as.numeric(factor(df$party.id), levels=unique(df$party.id))
num.country<-length(unique(country))
num.party<-length(unique(party))


X<-cbind(1,  df$log.partyyears, df$organisation, df$newfamfirst,
		df$dm.centered, df$dm.centered.squared, 
		df$finance_party_qualify,df$election_year_dummy,
		df$indPOL, df$efNPP,  
		df$elec_coalition, 
		df$votes.history.centered, 
		df$logseats.centered,
		df$government, 
		df$EU_parl,
		df$reg_gov.lagged)

colnames(X)<-c("Intercept", "Party.Life.Length", "Organisation", "NewFamFirst",
		  "DM","DM.squared", "Finance", "Election.Dummy", 
		"Polarization", "efNPP", 
		"Electoral.Coalition",
		"Votes", "Seat.Shares", 
		"Government", 
		"EU.Parliament", "Regional")



load("All.Results.TableA4")

### Posterior Summaries
Beta.2<-rbind(All.Results$Beta2[27201:27500,,1], All.Results$Beta2[27201:27500,,2], All.Results$Beta2[27201:27500,,3])
Beta.3<-rbind(All.Results$Beta3[27201:27500,,1], All.Results$Beta3[27201:27500,,2], All.Results$Beta3[27201:27500,,3])
colnames(Beta.2)<-All.Results$vars
colnames(Beta.3)<-All.Results$vars
Sigma.Country<-rbind(All.Results$Sigma.country[27201:27500,,1], All.Results$Sigma.country[27201:27500,,2], All.Results$Sigma.country[27201:27500,,3])
Sigma.Party<-rbind(All.Results$Sigma.party[27201:27500,,1], All.Results$Sigma.party[27201:27500,,2], All.Results$Sigma.party[27201:27500,,3])
Reffect.Country<-rbind(All.Results$Reffect.country[27201:27500,,1],All.Results$Reffect.country[27201:27500,,2], All.Results$Reffect.country[27201:27500,,3])
Reffect.Country.Merge<-Reffect.Country[,1:num.country]
Reffect.Country.Dissolution<-Reffect.Country[,(num.country+1):(2*num.country)]
Reffect.Party<-rbind(All.Results$Reffect.party[27201:27500,,1],All.Results$Reffect.party[27201:27500,,2], All.Results$Reffect.party[27201:27500,,3])
Reffect.Party.Merge<-Reffect.Party[,1:num.party]
Reffect.Party.Dissolution<-Reffect.Party[,(num.party+1):(2*num.party)]


## Marginal Effects
dummies<-c(3, 4, 7,8,11,14, 15,16)
continuous<-c(9,10, 12,13)

Marginal.prob<-matrix(NA, nrow=(2+length(dummies)+length(continuous))*2, ncol=5)
colnames(Marginal.prob)<-c("Dep.Variable", "Covariate", "Predictive Comparison",  "90% CI - Lower", "90% CI - Higher")
Marginal.prob[,1]<-c(rep("Dissolution",(2+length(dummies)+length(continuous))) ,rep("Merger",(2+length(dummies)+length(continuous))))
Marginal.prob[,2]<-rep(colnames(X)[sort(c(2,5,dummies, continuous))],2)

Odds<-matrix(NA, nrow=(2+length(dummies)+length(continuous))*2, ncol=5)
colnames(Odds)<-c("Dep.Variable", "Covariate", "Predictive Comparison",  "90% CI - Lower", "90% CI - Higher")
Odds[,1]<-c(rep("Dissolution",(2+length(dummies)+length(continuous))) ,rep("Merger",(2+length(dummies)+length(continuous))))
Odds[,2]<-rep(colnames(X)[sort(c(2,5,dummies, continuous))],2)

Ratio.NewOld<-matrix(NA, nrow=(2+length(dummies)+length(continuous))*2, ncol=5)
colnames(Ratio.NewOld)<-c("Dep.Variable", "Covariate", "Predictive Comparison",  "90% CI - Lower", "90% CI - Higher")
Ratio.NewOld[,1]<-c(rep("Dissolution",(2+length(dummies)+length(continuous))) ,rep("Merger",(2+length(dummies)+length(continuous))))
Ratio.NewOld[,2]<-rep(colnames(X)[sort(c(2,5,dummies, continuous))],2)

Ratio.OldNew<-matrix(NA, nrow=(2+length(dummies)+length(continuous))*2, ncol=5)
colnames(Ratio.OldNew)<-c("Dep.Variable", "Covariate", "Predictive Comparison",  "90% CI - Lower", "90% CI - Higher")
Ratio.OldNew[,1]<-c(rep("Dissolution",(2+length(dummies)+length(continuous))) ,rep("Merger",(2+length(dummies)+length(continuous))))
Ratio.OldNew[,2]<-rep(colnames(X)[sort(c(2,5,dummies, continuous))],2)

Odds<-matrix(NA, nrow=(2+length(dummies)+length(continuous))*2, ncol=5)
colnames(Odds)<-c("Dep.Variable", "Covariate", "Predictive Comparison",  "90% CI - Lower", "90% CI - Higher")
Odds[,1]<-c(rep("Dissolution",(2+length(dummies)+length(continuous))) ,rep("Merger",(2+length(dummies)+length(continuous))))
Odds[,2]<-rep(colnames(X)[sort(c(2,5,dummies, continuous))],2)


for (j in dummies) {
X.0<-X
X.0[,j]<-0
X.1<-X
X.1[,j]<-1

Dissolution.New<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1]))
)) 


Dissolution.Old<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1]))
))

Merger.New<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) 
))

Merger.Old<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1]))
)
)

Odds.Dissolution<-exp(Beta.3[,j])-1
Odds.Merger<-exp(Beta.2[,j])-1


Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),3]<-c(mean(Dissolution.New-Dissolution.Old), mean(Merger.New-Merger.Old))
Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution.New-Dissolution.Old), p=0.9), HPDinterval(as.mcmc(Merger.New-Merger.Old), p=0.9)),ncol=2,byrow=TRUE)


Ratio.OldNew[grep(colnames(X)[j],Ratio.OldNew[,2]),3]<-c(mean(Dissolution.Old/Dissolution.New), mean(Merger.Old/Merger.New))
Ratio.OldNew[grep(colnames(X)[j],Ratio.OldNew[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution.Old/Dissolution.New), p=0.9), HPDinterval(as.mcmc(Merger.Old/Merger.New), p=0.9)),ncol=2,byrow=TRUE)

Ratio.NewOld[grep(colnames(X)[j],Ratio.NewOld[,2]),3]<-c(mean(Dissolution.New/Dissolution.Old), mean(Merger.New/Merger.Old))
Ratio.NewOld[grep(colnames(X)[j],Ratio.NewOld[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution.New/Dissolution.Old), p=0.9), HPDinterval(as.mcmc(Merger.New/Merger.Old), p=0.9)),ncol=2,byrow=TRUE)

Odds[grep(colnames(X)[j],Odds[,2]),3]<-c(mean(Odds.Dissolution), mean(Odds.Merger))
Odds[grep(colnames(X)[j],Odds[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Odds.Dissolution), p=0.9), HPDinterval(as.mcmc(Odds.Merger), p=0.9)),ncol=2,byrow=TRUE)

}


for (j in continuous) {
X.0<-X
X.1<-X
X.1[,j]<-X.0[,j]+sd(X[,j])


Dissolution.New<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1]))
)) 


Dissolution.Old<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1]))
))

Merger.New<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) 
))

Merger.Old<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1]))
)
)

Odds.Dissolution<-exp(Beta.3[,j]*sd(X[,j]))-1
Odds.Merger<-exp(Beta.2[,j]*sd(X[,j]))-1


Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),3]<-c(mean(Dissolution.New-Dissolution.Old), mean(Merger.New-Merger.Old))
Marginal.prob[grep(colnames(X)[j],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution.New-Dissolution.Old), p=0.9), HPDinterval(as.mcmc(Merger.New-Merger.Old), p=0.9)),ncol=2,byrow=TRUE)


Ratio.OldNew[grep(colnames(X)[j],Ratio.OldNew[,2]),3]<-c(mean(Dissolution.Old/Dissolution.New), mean(Merger.Old/Merger.New))
Ratio.OldNew[grep(colnames(X)[j],Ratio.OldNew[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution.Old/Dissolution.New), p=0.9), HPDinterval(as.mcmc(Merger.Old/Merger.New), p=0.9)),ncol=2,byrow=TRUE)

Ratio.NewOld[grep(colnames(X)[j],Ratio.NewOld[,2]),3]<-c(mean(Dissolution.New/Dissolution.Old), mean(Merger.New/Merger.Old))
Ratio.NewOld[grep(colnames(X)[j],Ratio.NewOld[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution.New/Dissolution.Old), p=0.9), HPDinterval(as.mcmc(Merger.New/Merger.Old), p=0.9)),ncol=2,byrow=TRUE)

Odds[grep(colnames(X)[j],Odds[,2]),3]<-c(mean(Odds.Dissolution), mean(Odds.Merger))
Odds[grep(colnames(X)[j],Odds[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Odds.Dissolution), p=0.9), HPDinterval(as.mcmc(Odds.Merger), p=0.9)),ncol=2,byrow=TRUE)

}


 
# Duration
X.0<-X
X.1<-X
X.1[,2]<-log(exp(X.0[,2]+sd(X[,2])))

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Marginal.prob[grep(colnames(X)[2],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[2],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)

# Quadratic term for DM
X.0<-X
X.1<-X
X.1[,5]<-X[,5]+sd(X[,5])
X.1[,6]<-X.1[,5]^2

Dissolution<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Merger<-sapply(1:nrow(Beta.2), function(s) mean(
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.1%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.1%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])) -
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])/(1+
exp(X.0%*%Beta.3[s,]+matrix(Reffect.Country[s,],ncol=2)[country,2]+matrix(Reffect.Party[s,],ncol=2)[party,2])+
exp(X.0%*%Beta.2[s,]+matrix(Reffect.Country[s,],ncol=2)[country,1]+matrix(Reffect.Party[s,],ncol=2)[party,1])))
)

Marginal.prob[grep(colnames(X)[5],Marginal.prob[,2]),3]<-c(mean(Dissolution), mean(Merger))
Marginal.prob[grep(colnames(X)[5],Marginal.prob[,2]),4:5]<-matrix(c(HPDinterval(as.mcmc(Dissolution), p=0.9), HPDinterval(as.mcmc(Merger), p=0.9)),ncol=2,byrow=TRUE)

## Figure

Marginal.prob<-data.frame(Marginal.prob)
for (k in 3:ncol(Marginal.prob)) {
Marginal.prob[,k]<-as.numeric(levels(Marginal.prob[,k]))[Marginal.prob[,k]]
}
names(Marginal.prob)<-c("Dep.Variable", "Covariate", "Mean","Lo.CI", "Hi.CI")
Marginal.prob[,3:5]<-100*Marginal.prob[,3:5]

Marginal.prob.Figure2<-Marginal.prob[c(2:3,5,7:14,
				16:17,19,21:28),]

#Marginal.prob.Figure2.Alternative<-Marginal.prob[c(2,3,5,7,8,9,10,11,12,13,14,
#				16,17,19,21,22,23,24,25,26,27,28),]

## Reorder this based on our final definition of vars
Marginal.prob.Figure2$Covariate<- factor(Marginal.prob.Figure2$Covariate, 
			levels = rev(c(
				"Seat.Shares","Votes","Polarization",
				"Finance", "EU.Parliament","Regional",
				 "Government","efNPP","Electoral.Coalition",
				"Organisation", "NewFamFirst")),
			labels=rev(c("Seat Share", "Electoral Performance", "Electoral Polarization",
			"State Funding", "EP Access", "Regional Government",
			"National Government", "Coalition Potential",
			"Electoral Coalition",
			"Societal Rootedness", "Ideological Novelty")))


ggplot(Marginal.prob.Figure2,
 aes(y=Covariate, x=Mean)) + 
    geom_errorbarh(aes(xmin=Lo.CI, 
	xmax=Hi.CI, height=.2), size=1, colour="black") + facet_wrap(~Dep.Variable)+
    geom_point(size=3)+
theme_bw()+xlab("Change in death-specific hazards")+ylab("")+
geom_hline(yintercept=0, linetype="longdash", colour="gray40")+
theme(strip.text.x = element_text(size = 12, face="bold"))+
geom_vline(xintercept=0, linetype="longdash", colour="gray40")+
theme(axis.text.y = element_text(size=12)) +
 theme(axis.title=element_text(size=12))



rm(list=ls())


########################## TABLE A.5 (ONLINE APPENDIX) #####################################################################################################################################################################################################
load("All.Results.Table2.Cols12")

Sigma.Country<-rbind(All.Results$Sigma.country[26751:27500,,1], All.Results$Sigma.country[26751:27500,,2], All.Results$Sigma.country[26751:27500,,3])
Sigma.Party<-rbind(All.Results$Sigma.party[26751:27500,,1], All.Results$Sigma.party[26751:27500,,2], All.Results$Sigma.party[26751:27500,,3])


# UPPER PANEL (Party-specific covariance matrix and correlations)

Varcov.Party<-round(cbind(10*colMeans(Sigma.Party),10*HPDinterval(as.mcmc(Sigma.Party), p=0.9)),digits=2)
colnames(Varcov.Party)<-c("Estimate", "CI - Lower", "CI - Higher")
rownames(Varcov.Party)<-c("Var.Mergers", "Covariance", "Covariance", "Var.Dissolution")
Varcov.Party

#Correlation
mean(Sigma.Party[,3]/(sqrt(Sigma.Party[,1])*sqrt(Sigma.Party[,4])))
HPDinterval(as.mcmc(Sigma.Party[,3]/(sqrt(Sigma.Party[,1])*sqrt(Sigma.Party[,4])),p=0.9))[1:2]



# LOWER PANEL (Country-specific covariance matrix and correlations)
Varcov.Country<-round(cbind(10*colMeans(Sigma.Country),10*HPDinterval(as.mcmc(Sigma.Country), p=0.9)),digits=2)
colnames(Varcov.Country)<-c("Estimate", "CI - Lower", "CI - Higher")
rownames(Varcov.Country)<-c("Var.Mergers", "Covariance", "Covariance", "Var.Dissolution")
Varcov.Country

#Correlation
mean(Sigma.Country[,3]/(sqrt(Sigma.Country[,1])*sqrt(Sigma.Country[,4])))
HPDinterval(as.mcmc(Sigma.Country[,3]/(sqrt(Sigma.Country[,1])*sqrt(Sigma.Country[,4])),p=0.9))[1:2]


rm(list=ls())

########################## TABLE A.6 (ONLINE APPENDIX) #####################################################################################################################################################################################################
options(warn=-1)
library(nnet)

df<-read.csv("data.survival.csv")

df$logseats.centered<-(df$log.seats-mean(df$log.seats, na.rm=TRUE))/(2*sd(df$log.seats, na.rm=TRUE))
df$dm.centered<-(df$dm-mean(df$dm, na.rm=TRUE))/(2*sd(df$dm, na.rm=TRUE))
df$dm.centered.squared<-df$dm.centered^2
df$dm.centered.squared.bis<-(df$dm^2-mean(df$dm^2))/(2*sd(df$dm^2,na.rm=TRUE))


df<-subset(df, select=c("merged", "dissolved",
		"organisation", "newfamfirst","country", "case_id",
		"dm.centered", "dm.centered.squared", "dm.centered.squared.bis",
		"finance_party_qualify","election_year_dummy",
		"indPOL", "efNPP", "insider", "elec_coalition",
		"log.seats",
		"logseats.centered",
		 "country.id", "party.id",
		"country", "party.name",
		"votes.history.centered",
		"government", 
		"reg_gov.lagged", 
		 "EU_parl",
		"log.partyyears",
		"year_exist"))
df<-na.exclude(df)
attach(df)

Y<-cbind(df$merged, df$dissolved)
Y<-cbind(ifelse(rowSums(Y)==0,1,0),Y)
y<-c(sapply(1:nrow(Y), function(i) which(Y[i,]==1)))
n<-length(y)          # Number of obs


### MERGER DEPENDS ON DISSOLUTION (RHO^DM)

# COLUMN 1
years.centered<-(year_exist-mean(year_exist))/sd(year_exist)
years.centered.2<-years.centered^2


X2<-cbind(1,years.centered, years.centered.2, organisation, newfamfirst,
		finance_party_qualify,
		government, efNPP)

X3<-cbind(1, years.centered, years.centered.2, organisation, newfamfirst,
		 logseats.centered,votes.history.centered, EU_parl, reg_gov.lagged)


#########################################
# log likelihood

llik.multi.rho4 <- function(par, y, X2, X3){
# the number of parameters
k0 <- ncol(X2);k1 <- ncol(X3)
k <- k0+k1

# extract parameters
beta0 <- par[1:k0]
beta1 <- par[(k0+1):(k0+k1)]
sigma10 <- par[k+1]

## probabilities: deterministic nested dependent risks
# linear predictors of hazard by risk
h0 <- X2%*%beta0
h1 <- X3%*%beta1
# base hazard 
xb0 <- h0-beta0[1]-(beta0[2]*X2[,2])
xb1 <- h1-beta1[1]-(beta1[2]*X3[,2])

# correlated risks
p2 <- exp(h0+(sigma10*xb1))/(1+exp(h0+(sigma10*xb1))+exp(h1))
p3 <- exp(h1)/(1+exp(h0+(sigma10*xb1))+exp(h1))
p1 <- 1/(1+exp(h0+(sigma10*xb1))+exp(h1))

# nested log likelihood
llik <- sum(log(p1[y==1])) +
   sum(log(p2[y==2])) 
   sum(log(p3[y==3])) 
return(llik)
}

#########################################
# probabilities of every risk
prob.multi.rho4 <- function(par, y, x0, x1){
# the number of parameters
k0 <- ncol(x0);k1 <- ncol(x1)
k <- k0+k1

# extract parameters
beta0 <- par[1:k0]
beta1 <- par[(k0+1):(k0+k1)]
sigma10 <- par[k+1]

## probabilities: deterministic nested dependent risks
# linear predictors of hazard by risk


h0 <- x0%*%beta0
h1 <- x1%*%beta1
# base hazard 
xb0 <- h0-beta0[1]-(beta0[2]*x0[,2])
xb1 <- h1-beta1[1]-(beta1[2]*x1[,2])

# correlated risks
p2 <- exp(h0+(sigma10*xb1))/(1+exp(h0+(sigma10*xb1))+exp(h1))
p3 <- exp(h1)/(1+exp(h0+(sigma10*xb1))+exp(h1))
p1 <- 1/(1+exp(h0+(sigma10*xb1))+exp(h1))

return(cbind(p1,p2,p3))
}



k0 <- ncol(X2);k1 <- ncol(X3)
 
start0 <- rep(0,k0);start1 <- rep(0,k1);
start0 <- glm(as.integer(y==2) ~ X2[,-1], family=binomial)$coefficients    
start1 <- glm(as.integer(y==3) ~ X3[,-1], family=binomial)$coefficients  
start.all  <- c(start0,start1,0)



# optimization  
res <- optim(start.all, llik.multi.rho4, method = "BFGS", hessian = TRUE, control = list(fnscale = -1),
             y = y, X2 = X2, X3 = X3)


#### parameter estimates
names(res$par) <- c(colnames(X2),colnames(X3),"sigma10")
res$prob <- prob.multi.rho4(res$par, y, X2, X3)
res$X2 <- X2
res$X3 <- X3
res$y <- y

#Correlation: 
estimate<-res$par[ncol(res$hessian)]
sd<-sqrt(solve(-res$hessian[ncol(res$hessian),ncol(res$hessian)]))


round(estimate,digits=2)
round(sd, digits=2)


# COLUMN 2
X2<-cbind(1,log.partyyears, organisation, newfamfirst,
		finance_party_qualify,
		government, efNPP)

X3<-cbind(1, log.partyyears, organisation, newfamfirst,
		 logseats.centered,votes.history.centered, EU_parl, reg_gov.lagged)



k0 <- ncol(X2);k1 <- ncol(X3)
 
start0 <- rep(0,k0);start1 <- rep(0,k1);
start0 <- glm(as.integer(y==2) ~ X2[,-1], family=binomial)$coefficients    
start1 <- glm(as.integer(y==3) ~ X3[,-1], family=binomial)$coefficients  
start.all  <- c(start0,start1,0)



# optimization  
res <- optim(start.all, llik.multi.rho4, method = "BFGS", hessian = TRUE, control = list(fnscale = -1),
             y = y, X2 = X2, X3 = X3)


names(res$par) <- c(colnames(X2),colnames(X3),"sigma10")
res$prob <- prob.multi.rho4(res$par, y, X2, X3)
res$X2 <- X2
res$X3 <- X3
res$y <- y

#Correlation: 
estimate<-res$par[ncol(res$hessian)]
sd<-sqrt(solve(-res$hessian[ncol(res$hessian),ncol(res$hessian)]))

round(estimate,digits=2)
round(sd, digits=2)



#####  DISOLUTION DEPENDS ON MERGER (RHO^MD)

# COLUMN 1

X3<-cbind(1,years.centered, years.centered.2, organisation, newfamfirst,
government,elec_coalition,
efNPP)

X2<-cbind(1, years.centered, years.centered.2, organisation, newfamfirst,government,
		 logseats.centered,votes.history.centered, EU_parl, reg_gov.lagged)



k0 <- ncol(X2);k1 <- ncol(X3)
 
start0 <- rep(0,k0);start1 <- rep(0,k1);
start0 <- glm(as.integer(y==2) ~ X2[,-1], family=binomial)$coefficients    
start1 <- glm(as.integer(y==3) ~ X3[,-1], family=binomial)$coefficients  
start.all  <- c(start0,start1,0)



# optimization  
res <- optim(start.all, llik.multi.rho4, method = "BFGS", hessian = TRUE, control = list(fnscale = -1),
             y = y, X2 = X2, X3 = X3)


#### parameter estimates
names(res$par) <- c(colnames(X2),colnames(X3),"sigma10")
res$prob <- prob.multi.rho4(res$par, y, X2, X3)
res$X2 <- X2
res$X3 <- X3
res$y <- y

#Correlation: 
estimate<-res$par[ncol(res$hessian)]
sd<-sqrt(solve(-res$hessian[ncol(res$hessian),ncol(res$hessian)]))

round(estimate, digits=2)
round(sd,digits=2)


# COLUMN 2

X3<-cbind(1,log.partyyears, organisation, newfamfirst,
government,elec_coalition,
efNPP)

X2<-cbind(1, log.partyyears, organisation, newfamfirst,government,
		 logseats.centered,votes.history.centered, EU_parl, reg_gov.lagged)


k0 <- ncol(X2);k1 <- ncol(X3)
 
start0 <- rep(0,k0);start1 <- rep(0,k1);
start0 <- glm(as.integer(y==2) ~ X2[,-1], family=binomial)$coefficients    
start1 <- glm(as.integer(y==3) ~ X3[,-1], family=binomial)$coefficients  
start.all  <- c(start0,start1,0)



# optimization  
res <- optim(start.all, llik.multi.rho4, method = "BFGS", hessian = TRUE, control = list(fnscale = -1),
             y = y, X2 = X2, X3 = X3)


#### parameter estimates
names(res$par) <- c(colnames(X2),colnames(X3),"sigma10")
res$prob <- prob.multi.rho4(res$par, y, X2, X3)
res$X2 <- X2
res$X3 <- X3
res$y <- y

#Correlation: 
estimate<-res$par[ncol(res$hessian)]
sd<-sqrt(solve(-res$hessian[ncol(res$hessian),ncol(res$hessian)]))

round(estimate, digits=2)
round(sd, digits=2)



